package devmgr.api.model;

import devmgr.api.symbol.Location;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * This represents a Host Interface Port that is on One of the Controllers on a Storage System.  This is NOT the port on the host system.
 */

public interface HostInterfacePort {
    public String getInterfaceId() ;

    /**
     * Gets the physical location information for the port
     * @return
     */
    public Location getPhysicalLocation();

    /*
     * The channel number of the host port.
     */
    public int getChannel () ;


    @XmlElement
    public abstract String getAddressId();

    /**
     * Retrieve the address ID string formatted in a nice, more consistent manner.
     * More appropriate for displays.
     * The default implementation just returns the address ID string.  Override for
     * more specific type formatting.
     *
     * The address of the port.
     */
    @XmlElement(name="portAddress")
    public String getNiceAddressId() ;

    /**
     * Sets the controller id for this HBA if this port is on our controller and not a host port
     *
     * The identifier of the controller of this interface port if the port
     * is on the controller and not on a host.
     */
    public String getControllerId() ;
    public void setControllerId(String id);


}
