package devmgr.api.model;

import devmgr.api.symbol.*;

/**
 * Author: khulques
 * Date: 1/18/14
 * Description - Delegate class to hide some of the less used fields of a Mel Event
 * like RawData.
 */
public class MelEntryDelegate {
    public MelEntryDelegate() {
    }

    public MelEntryDelegate(MelEntry x) {
        melEntry.setSequenceNumber(x.getSequenceNumber());
        melEntry.setTimeStamp(x.getTimeStamp());
        melEntry.setSenseKey(x.getSenseKey());
        melEntry.setPriority(x.getPriority());
        melEntry.setLocationValid(x.isLocationValid());
        melEntry.setExtComponentLocation(x.getExtComponentLocation());
        melEntry.setASC(x.getASC());
        melEntry.setASCQ(x.getASCQ());
        melEntry.setCategory(x.getCategory());
        melEntry.setComponentLocation(x.getComponentLocation());
        melEntry.setControlParams(x.getControlParams());
        melEntry.setComponentType(x.getComponentType());
        melEntry.setEventSourceController(x.getEventSourceController());
    }
    private final MelEntry melEntry = new MelEntry();

    /**
     * The raw MelEntry.
     * @return
     */
    protected MelEntry getMelEntry() {
        return melEntry;
    }

    /**
     * The sequence number of the MEL entry.
     * The controller maintains a unique, monotonically increasing 64-bit sequence number value and stamps each
     * MEL entry with the next value of this counter.
     * @return
     */
    public long getSequenceNumber() {
        return melEntry.getSequenceNumber();
    }

    public void setSequenceNumber(long x) {
        melEntry.setSequenceNumber(x);
    }

    /**
     * An integer value that indicates the specific type of event being reported.
     * @return
     */
    public int getEventType() {
        return melEntry.getEventType();
    }

    public void setEventType(int x) {
        melEntry.setEventType(x);
    }

    /**
     * The category into which this event falls. This value identifies the general type of activity or event that
     * occurred and caused the entry to be generated.
     * @return
     */
    public EventCategory getCategory() {
        return melEntry.getCategory();
    }

    public void setCategory(EventCategory x) {
        melEntry.setCategory(x);
    }

    /**
     * The type of component that is associated with this entry.
     * @return
     */
    public EventComponentType getComponentType() {
        return melEntry.getComponentType();
    }

    public void setComponentType(EventComponentType x) {
        melEntry.setComponentType(x);
    }

    /**
     * The location, or other identifying value, of the component associated with this entry.
     * @return
     */
    public ComponentLocation getComponentLocation() {
        return melEntry.getComponentLocation();
    }

    public void setComponentLocation(ComponentLocation x) {
        melEntry.setComponentLocation(x);
    }

    /**
     * A true/false indication of whether the ComponentLocation field is valid for this entry.
     * @return
     */
    public boolean isLocationValid() {
        return melEntry.isLocationValid();
    }

    public void setLocationValid(boolean x) {
        melEntry.setLocationValid(x);
    }

    /**
     * The priority code associated with this event.
     * @return
     */
    public EventPriority getPriority() {
        return melEntry.getPriority();
    }

    public void setPriority(EventPriority x) {
        melEntry.setPriority(x);
    }

    /**
     * The controller that is the source of the event (Controller A or B).
     * @return
     */
    public int getEventSourceController() {
        return melEntry.getEventSourceController();
    }

    public void setEventSourceController(int x) {
        melEntry.setEventSourceController(x);
    }

    /**
     * The Additional Sense Code value associated with this event.
     * @return
     */
    public int getASC() {
        return melEntry.getASC();
    }

    public void setASC(int x) {
        melEntry.setASC(x);
    }


    /**
     * The Additional Sense Code Qualifier associated with this event.
     * @return
     */
    public int getASCQ() {
        return melEntry.getASCQ();
    }

    public void setASCQ(int x) {
        melEntry.setASCQ(x);
    }

    /**
     * The Sense Key value associated with this event, or zero if no key is applicable.
     * @return
     */
    public int getSenseKey() {
        return melEntry.getSenseKey();
    }

    public void setSenseKey(int x) {
        melEntry.setSenseKey(x);
    }

    /**
     * Extended component location information for this entry. This data type of this field is a union with
     * discriminator extLocType. If the discriminator is set to something other than 'unknown',
     * then the location information in this field overrides what is in the componentLocation field.
     * @return
     */
    public ExtendedComponentLocation getExtComponentLocation() {
        return melEntry.getExtComponentLocation();
    }

    public void setExtComponentLocation(ExtendedComponentLocation x) {
        melEntry.setExtComponentLocation(x);
    }

    /**
     * This field allows customized control over the handling of MEL events.
     * @return
     */
    public EventControl getControlParams() {
        return melEntry.getControlParams();
    }

    public void setControlParams(EventControl x) {
        melEntry.setControlParams(x);
    }



}
