package devmgr.api.rpc.protocol;

import devmgr.api.runtime.*;
import java.util.EnumSet;
import java.util.Collections;

public class RPCProtocol extends ApiDefinition
{
	public RPCProtocol() {
		super(-1, 1, m_TypeTable, m_ProcTable);
	}

	public static final int VERSION = 2;

	private static TypeSpec[] m_TypeTable;

	private static void __init0() {
		m_TypeTable[0] = new TypeSpec(TypeSpec.TypeCode.SHORT);
		m_TypeTable[1] = new TypeSpec(TypeSpec.TypeCode.BYTE);
		m_TypeTable[2] = new TypeSpec(TypeSpec.TypeCode.CHAR);
		m_TypeTable[3] = new TypeSpec(TypeSpec.TypeCode.INT);
		m_TypeTable[4] = new TypeSpec(TypeSpec.TypeCode.BOOLEAN);
		m_TypeTable[5] = new TypeSpec(TypeSpec.TypeCode.DOUBLE);
		m_TypeTable[6] = new TypeSpec(TypeSpec.TypeCode.LONG);
		m_TypeTable[7] = new TypeSpec(TypeSpec.TypeCode.FLOAT);

		m_TypeTable[8] = new EnumSpec(new EnumValue[] {
			new EnumValue("AUTH_DES", 3),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("AUTH_NONE", 0),
			new EnumValue("AUTH_DIGEST_HMAC256", -1430533118),
			new EnumValue("AUTH_UNIX", 1),
			new EnumValue("AUTH_DIGEST", -1430533119)
		}, RPCAuthType.class);

		m_TypeTable[9] = new EnumSpec(new EnumValue[] {
			new EnumValue("MSG_ACCEPTED", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("MSG_DENIED", 1)
		}, RPCReplyStatus.class);

		m_TypeTable[10] = new EnumSpec(new EnumValue[] {
			new EnumValue("AUTH_ERROR", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("RPC_MISMATCH", 0)
		}, RPCRejectedStatus.class);

		m_TypeTable[11] = new EnumSpec(new EnumValue[] {
			new EnumValue("AUTH_REJECTEDCRED", 2),
			new EnumValue("AUTH_INVALIDRESP", 6),
			new EnumValue("AUTH_TOOWEAK", 5),
			new EnumValue("AUTH_REJECTEDVERF", 4),
			new EnumValue("AUTH_OK", 0),
			new EnumValue("AUTH_BADCRED", 1),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("AUTH_FAILED", 7),
			new EnumValue("AUTH_BADVERF", 3)
		}, RPCAuthStatus.class);

		m_TypeTable[12] = new EnumSpec(new EnumValue[] {
			new EnumValue("CALL", 0),
			new EnumValue("__UNDEFINED", 464378545),
			new EnumValue("REPLY", 1)
		}, RPCMsgType.class);

		m_TypeTable[13] = new EnumSpec(new EnumValue[] {
			new EnumValue("PROG_MISMATCH", 2),
			new EnumValue("SUCCESS", 0),
			new EnumValue("PROC_UNAVAIL", 3),
			new EnumValue("SYSTEM_ERR", 5),
			new EnumValue("GARBAGE_ARGS", 4),
			new EnumValue("PROG_UNAVAIL", 1),
			new EnumValue("__UNDEFINED", 464378545)
		}, RPCAcceptedStatus.class);

		m_TypeTable[14] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("low", m_TypeTable[3]),
			new TypeBinding("high", m_TypeTable[3])
		}, RPCVersionRange.class, false);

		m_TypeTable[15] = new UnionSpec(false, "status", m_TypeTable[13], new AlternateBinding[] {
			new AlternateBinding(2, "versions", m_TypeTable[14])
		}, RPCAcceptedReplyBody.class);

		m_TypeTable[16] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("type", m_TypeTable[8]),
			new TypeBinding("info", new OpaqueSpec(0, true, OpaqueSpec.DataType.BINARY))
		}, RPCOpaqueAuth.class, false);

		m_TypeTable[17] = new UnionSpec(false, "status", m_TypeTable[10], new AlternateBinding[] {
			new AlternateBinding(0, "versions", m_TypeTable[14]),
			new AlternateBinding(1, "authStatus", m_TypeTable[11])
		}, RPCRejectedReply.class);

		m_TypeTable[18] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("rpcVersion", m_TypeTable[3]),
			new TypeBinding("programNo", m_TypeTable[3]),
			new TypeBinding("versionNo", m_TypeTable[3]),
			new TypeBinding("procedure", m_TypeTable[3]),
			new TypeBinding("credential", m_TypeTable[16]),
			new TypeBinding("verifier", m_TypeTable[16])
		}, RPCCallMsg.class, false);

		m_TypeTable[19] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("verifier", m_TypeTable[16]),
			new TypeBinding("body", m_TypeTable[15])
		}, RPCAcceptedReply.class, false);

		m_TypeTable[20] = new UnionSpec(false, "status", m_TypeTable[9], new AlternateBinding[] {
			new AlternateBinding(0, "acceptedReply", m_TypeTable[19]),
			new AlternateBinding(1, "rejectedReply", m_TypeTable[17])
		}, RPCReplyMsg.class);

		m_TypeTable[21] = new UnionSpec(false, "msgType", m_TypeTable[12], new AlternateBinding[] {
			new AlternateBinding(0, "callMsg", m_TypeTable[18]),
			new AlternateBinding(1, "replyMsg", m_TypeTable[20])
		}, RPCMsgBody.class);

		m_TypeTable[22] = new StructSpec(false, new TypeBinding[] {
			new TypeBinding("xid", m_TypeTable[3]),
			new TypeBinding("body", m_TypeTable[21])
		}, RPCMsg.class, false);
	}

	static
	{
		m_TypeTable = new TypeSpec[23];

		__init0();
	}

	private static ProcTableEntry[] m_ProcTable;
}
