package devmgr.api.runtime;

public class SubclassSpec
extends TypeSpec
{
    public TypeSpec superType;
    public Class<?> cls;
    
    public
    SubclassSpec(TypeSpec superType, Class<?> thisClass)
    {
        super(TypeSpec.TypeCode.SUBCLASS);
        this.superType = superType;
        this.cls = thisClass;
        
        // Do some validation here related to subclasses of the
        // OPAQUE and STRING types.  For those, we have to do special
        // processing, since we really want to treat them as subclasses,
        // but the underlying Java types are 'final', and cannot be
        // subclassed.  We also need to ensure that no attempt is made
        // to specify a subclass of an enumeration, since Java doesn't
        // allow that either.
        boolean bad = false;
        switch(superType.typeCode)
        {
            case OPAQUE:
            case STRING:
                if (thisClass != null)
                    bad = true;
                break;
                
            case SUBCLASS:
                SubclassSpec base = (SubclassSpec) superType;
                if ( (base.cls == null) && (this.cls != null) )
                    bad = true;
                else if ( (base.cls != null) && (this.cls == null) )
                    bad = true;
                else if (superType.typeCode == TypeCode.ENUM)
                    bad = true;
                break;
                
            default:
                break;
        }
        
        if (bad)
            throw new RuntimeException("Illegal SubclassSpec");
    }
}