package devmgr.api.runtime;

import java.io.InputStream;

/**
 * This class provides XdrDecoder capability for the data in an
 * arbitrary InputStream object.
 */
public class XdrStreamDecoder
extends XdrDecoder
{
    /**
     * Constructor.  Builds an XdrMessage out of the data from the
     * specified input stream.
     * @param is Input stream containing data for the message.
     * @throws DecodeException
     */
    public XdrStreamDecoder(InputStream is)
    throws DecodeException
    {
        super(extractMsg(is));
    }
    
    /**
     * Read the entire input stream into an XdrMessage structure.
     * @param is Input stream.
     * @return An XdrMessage object containing the message.
     * @throws DecodeException
     */
    private static XdrMessage 
    extractMsg(InputStream is)
    throws DecodeException
    {
        int bufSize = 8 * 1024;
        
        try
        {
            XdrMessage msg = new XdrMessage();

            // Accumulate data into full buffers, if possible, and add
            // each one to the message.
            byte[] buf = new byte[bufSize];
            int offset = 0;
            int amt;
            while ( (amt = is.read(buf, offset, buf.length - offset)) >= 0 )
            {
                offset += amt;
                
                if (offset == buf.length)
                {
                    msg.addBuffer(buf);
                    
                    buf = new byte[bufSize];
                    offset = 0;
                }
            }
            
            // If we have a partial buffer, add it to the message.
            if (offset > 0)
            {
                msg.addBuffer(buf, offset);
            }
            
            return msg;
        }
        
        catch (Exception ex)
        {
            throw DecodeException.build(ex, "Can't read input stream");
        }
    }
}