package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure represents a cache memory DIMM component and contains information pertinent to the management of such components. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(785)
public class CacheMemoryDimm implements Serializable {
	public CacheMemoryDimm() {
	}

	/** The SYMbol reference value that uniquely identifies an instance of a cache memory DIMM object. */
	@io.swagger.annotations.ApiModelProperty(value ="The SYMbol reference value that uniquely identifies an instance of a cache memory DIMM object." , required = true)
	@XmlElement(required = true)
	private String cacheMemoryDimmRef;

	/** @return The SYMbol reference value that uniquely identifies an instance of a cache memory DIMM object. */
	public String getCacheMemoryDimmRef() {
		return this.cacheMemoryDimmRef;
	}
	/** @param x The SYMbol reference value that uniquely identifies an instance of a cache memory DIMM object. */
	public void setCacheMemoryDimmRef(String x) {
		this.cacheMemoryDimmRef = x;
	}

	/** The operational status of the DIMM. */
	@io.swagger.annotations.ApiModelProperty(value ="The operational status of the DIMM." , required = true)
	@XmlElement(required = true)
	private DimmStatus status = DimmStatus.__UNDEFINED;

	/** @return The operational status of the DIMM. */
	public DimmStatus getStatus() {
		return this.status;
	}
	/** @param x The operational status of the DIMM. */
	public void setStatus(DimmStatus x) {
		this.status = x;
	}

	/** The capacity of the DIMM expressed in megabytes. */
	@io.swagger.annotations.ApiModelProperty(value ="The capacity of the DIMM expressed in megabytes." , required = true)
	@XmlElement(required = true)
	private int capacityInMegabytes;

	/** @return The capacity of the DIMM expressed in megabytes. */
	public int getCapacityInMegabytes() {
		return this.capacityInMegabytes;
	}
	/** @param x The capacity of the DIMM expressed in megabytes. */
	public void setCapacityInMegabytes(int x) {
		this.capacityInMegabytes = x;
	}

	/** The serial number of the DIMM. */
	@io.swagger.annotations.ApiModelProperty(value ="The serial number of the DIMM." , required = true)
	@XmlElement(required = true)
	private String serialNumber;

	/** @return The serial number of the DIMM. */
	public String getSerialNumber() {
		return this.serialNumber;
	}
	/** @param x The serial number of the DIMM. */
	public void setSerialNumber(String x) {
		this.serialNumber = x;
	}

	/** The LSI Logic part number of the DIMM. */
	@io.swagger.annotations.ApiModelProperty(value ="The LSI Logic part number of the DIMM." , required = true)
	@XmlElement(required = true)
	private String partNumber;

	/** @return The LSI Logic part number of the DIMM. */
	public String getPartNumber() {
		return this.partNumber;
	}
	/** @param x The LSI Logic part number of the DIMM. */
	public void setPartNumber(String x) {
		this.partNumber = x;
	}

	/** The OEM part number of the DIMM. */
	@io.swagger.annotations.ApiModelProperty(value ="The OEM part number of the DIMM." , required = true)
	@XmlElement(required = true)
	private String oemPartNumber;

	/** @return The OEM part number of the DIMM. */
	public String getOemPartNumber() {
		return this.oemPartNumber;
	}
	/** @param x The OEM part number of the DIMM. */
	public void setOemPartNumber(String x) {
		this.oemPartNumber = x;
	}

	/** The manufacturer part number of the DIMM. */
	@io.swagger.annotations.ApiModelProperty(value ="The manufacturer part number of the DIMM." , required = true)
	@XmlElement(required = true)
	private String manufacturerPartNumber;

	/** @return The manufacturer part number of the DIMM. */
	public String getManufacturerPartNumber() {
		return this.manufacturerPartNumber;
	}
	/** @param x The manufacturer part number of the DIMM. */
	public void setManufacturerPartNumber(String x) {
		this.manufacturerPartNumber = x;
	}

	/** The manufacturer part number of the DIMM. */
	@io.swagger.annotations.ApiModelProperty(value ="The manufacturer part number of the DIMM." , required = true)
	@XmlElement(required = true)
	private String manufacturer;

	/** @return The manufacturer part number of the DIMM. */
	public String getManufacturer() {
		return this.manufacturer;
	}
	/** @param x The manufacturer part number of the DIMM. */
	public void setManufacturer(String x) {
		this.manufacturer = x;
	}

	/** The manufacture date of the DIMM */
	@io.swagger.annotations.ApiModelProperty(value ="The manufacture date of the DIMM" , required = true)
	@XmlElement(required = true)
	private long manufactureDate;

	/** @return The manufacture date of the DIMM */
	public long getManufactureDate() {
		return this.manufactureDate;
	}
	/** @param x The manufacture date of the DIMM */
	public void setManufactureDate(long x) {
		this.manufactureDate = x;
	}

	/** The repair policy for the cache memory DIMM component. */
	@io.swagger.annotations.ApiModelProperty(value ="The repair policy for the cache memory DIMM component." , required = true)
	@XmlElement(required = true)
	private RepairPolicy repairPolicy;

	/** @return The repair policy for the cache memory DIMM component. */
	public RepairPolicy getRepairPolicy() {
		return this.repairPolicy;
	}
	/** @param x The repair policy for the cache memory DIMM component. */
	public void setRepairPolicy(RepairPolicy x) {
		this.repairPolicy = x;
	}

	/** The physical location of the cache memory DIMM. The parent reference in Location identifies the controller where the DIMM physically resides, and the position field is the parent-relative/like-component relative slot number of the DIMM, starting at 1. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the cache memory DIMM. The parent reference in Location identifies the controller where the DIMM physically resides, and the position field is the parent-relative/like-component relative slot number of the DIMM, starting at 1." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return The physical location of the cache memory DIMM. The parent reference in Location identifies the controller where the DIMM physically resides, and the position field is the parent-relative/like-component relative slot number of the DIMM, starting at 1. */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x The physical location of the cache memory DIMM. The parent reference in Location identifies the controller where the DIMM physically resides, and the position field is the parent-relative/like-component relative slot number of the DIMM, starting at 1. */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}

	/** This field is set to true if the DIMM is shared between processor and cache. It is set to false if the DIMM is dedicated to the cache. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is set to true if the DIMM is shared between processor and cache. It is set to false if the DIMM is dedicated to the cache." , required = true)
	@XmlElement(required = true)
	private boolean shared;

	/** @return This field is set to true if the DIMM is shared between processor and cache. It is set to false if the DIMM is dedicated to the cache. */
	public boolean isShared() {
		return this.shared;
	}
	/** @param x This field is set to true if the DIMM is shared between processor and cache. It is set to false if the DIMM is dedicated to the cache. */
	public void setShared(boolean x) {
		this.shared = x;
	}

	/** The module revision code of the DIMM. */
	@io.swagger.annotations.ApiModelProperty(value ="The module revision code of the DIMM." , required = true)
	@XmlElement(required = true)
	private String revisionCode;

	/** @return The module revision code of the DIMM. */
	public String getRevisionCode() {
		return this.revisionCode;
	}
	/** @param x The module revision code of the DIMM. */
	public void setRevisionCode(String x) {
		this.revisionCode = x;
	}
}
