package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** The proper string to display for the channel port number is a function of controller board ID, channel number, channel type (CHANNEL_TYPE_HOSTSIDE or CHANNEL_TYPE_DRIVESIDE), and channel port number. It is the responsibility of management software to locate the proper string (e.g., in a properties file) based on these values */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(797)
public class ChannelPort implements Serializable,devmgr.api.model.Identifiable {
	public ChannelPort() {
	}

	/** A reference to this channel port. */
	@io.swagger.annotations.ApiModelProperty(value ="A reference to this channel port." , required = true)
	@XmlElement(required = true)
	private String portRef;

	/** @return A reference to this channel port. */
	public String getPortRef() {
		return this.portRef;
	}
	/** @param x A reference to this channel port. */
	public void setPortRef(String x) {
		this.portRef = x;
	}

	/** The parent of the channel port object (minihub, controller, or ESM). */
	@io.swagger.annotations.ApiModelProperty(value ="The parent of the channel port object (minihub, controller, or ESM)." , required = true)
	@XmlElement(required = true)
	private ChannelPortParent portParent;

	/** @return The parent of the channel port object (minihub, controller, or ESM). */
	public ChannelPortParent getPortParent() {
		return this.portParent;
	}
	/** @param x The parent of the channel port object (minihub, controller, or ESM). */
	public void setPortParent(ChannelPortParent x) {
		this.portParent = x;
	}

	/** The identifying number assigned to this channel port. The range for port numbers is 1..n. If the port number cannot be determined, this field is set to zero. */
	@io.swagger.annotations.ApiModelProperty(value ="The identifying number assigned to this channel port. The range for port numbers is 1..n. If the port number cannot be determined, this field is set to zero." , required = true)
	@XmlElement(required = true)
	private int portNumber;

	/** @return The identifying number assigned to this channel port. The range for port numbers is 1..n. If the port number cannot be determined, this field is set to zero. */
	public int getPortNumber() {
		return this.portNumber;
	}
	/** @param x The identifying number assigned to this channel port. The range for port numbers is 1..n. If the port number cannot be determined, this field is set to zero. */
	public void setPortNumber(int x) {
		this.portNumber = x;
	}

	/** The number of the associated channel. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of the associated channel." , required = true)
	@XmlElement(required = true)
	private int channel;

	/** @return The number of the associated channel. */
	public int getChannel() {
		return this.channel;
	}
	/** @param x The number of the associated channel. */
	public void setChannel(int x) {
		this.channel = x;
	}

	/** The type of the associated channel - either host-side or drive-side. */
	@io.swagger.annotations.ApiModelProperty(value ="The type of the associated channel - either host-side or drive-side." , required = true)
	@XmlElement(required = true)
	private ChannelType channelType = ChannelType.__UNDEFINED;

	/** @return The type of the associated channel - either host-side or drive-side. */
	public ChannelType getChannelType() {
		return this.channelType;
	}
	/** @param x The type of the associated channel - either host-side or drive-side. */
	public void setChannelType(ChannelType x) {
		this.channelType = x;
	}

	/** The physical location of the channel port. The parent reference in Location identifies the physical CRU where the port is located, and the position field is the parent-relative/like-port relative number of the port, starting at 1. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical location of the channel port. The parent reference in Location identifies the physical CRU where the port is located, and the position field is the parent-relative/like-port relative number of the port, starting at 1." , required = true)
	@XmlElement(required = true)
	private Location physicalLocation;

	/** @return The physical location of the channel port. The parent reference in Location identifies the physical CRU where the port is located, and the position field is the parent-relative/like-port relative number of the port, starting at 1. */
	public Location getPhysicalLocation() {
		return this.physicalLocation;
	}
	/** @param x The physical location of the channel port. The parent reference in Location identifies the physical CRU where the port is located, and the position field is the parent-relative/like-port relative number of the port, starting at 1. */
	public void setPhysicalLocation(Location x) {
		this.physicalLocation = x;
	}

	/** This field is true if a trunk connection has been established and is being maintained on this controller or ESM channel port. This field is always false if the channel port is on a controller or ESM that does not have a Fibre Channel I/O interface type, or if the channel port is associated with a host-side channel. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is true if a trunk connection has been established and is being maintained on this controller or ESM channel port. This field is always false if the channel port is on a controller or ESM that does not have a Fibre Channel I/O interface type, or if the channel port is associated with a host-side channel." , required = true)
	@XmlElement(required = true)
	private boolean isTrunkActive;

	/** @return This field is true if a trunk connection has been established and is being maintained on this controller or ESM channel port. This field is always false if the channel port is on a controller or ESM that does not have a Fibre Channel I/O interface type, or if the channel port is associated with a host-side channel. */
	public boolean isIsTrunkActive() {
		return this.isTrunkActive;
	}
	/** @param x This field is true if a trunk connection has been established and is being maintained on this controller or ESM channel port. This field is always false if the channel port is on a controller or ESM that does not have a Fibre Channel I/O interface type, or if the channel port is associated with a host-side channel. */
	public void setIsTrunkActive(boolean x) {
		this.isTrunkActive = x;
	}
	@Override
	public String getId(){
		return portRef;
	}
}
