package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is embedded in a VolumeGroup object and provides information about the Disk Pool. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(480)
public class DiskPoolData implements Serializable {
	public DiskPoolData() {
	}

	/** The number of drives reserved for reconstruction of failed drives. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of drives reserved for reconstruction of failed drives." , required = true)
	@XmlElement(required = true)
	private int reconstructionReservedDriveCount;

	/** @return The number of drives reserved for reconstruction of failed drives. */
	public int getReconstructionReservedDriveCount() {
		return this.reconstructionReservedDriveCount;
	}
	/** @param x The number of drives reserved for reconstruction of failed drives. */
	public void setReconstructionReservedDriveCount(int x) {
		this.reconstructionReservedDriveCount = x;
	}

	/** The pool capacity reserved to hold rebuild data (in bytes). This value is calculated from the reconstructionReservedDriveCount. */
	@io.swagger.annotations.ApiModelProperty(value ="The pool capacity reserved to hold rebuild data (in bytes). This value is calculated from the reconstructionReservedDriveCount." , required = true)
	@XmlElement(required = true)
	private long reconstructionReservedAmt;

	/** @return The pool capacity reserved to hold rebuild data (in bytes). This value is calculated from the reconstructionReservedDriveCount. */
	public long getReconstructionReservedAmt() {
		return this.reconstructionReservedAmt;
	}
	/** @param x The pool capacity reserved to hold rebuild data (in bytes). This value is calculated from the reconstructionReservedDriveCount. */
	public void setReconstructionReservedAmt(long x) {
		this.reconstructionReservedAmt = x;
	}

	/** The reserved capacity that is currently available to hold rebuilt data (dynamic). If all of the reserved capacity is available, then this value will equal the reconstructionReservedDriveCount. */
	@io.swagger.annotations.ApiModelProperty(value ="The reserved capacity that is currently available to hold rebuilt data (dynamic). If all of the reserved capacity is available, then this value will equal the reconstructionReservedDriveCount." , required = true)
	@XmlElement(required = true)
	private int reconstructionReservedDriveCountCurrent;

	/** @return The reserved capacity that is currently available to hold rebuilt data (dynamic). If all of the reserved capacity is available, then this value will equal the reconstructionReservedDriveCount. */
	public int getReconstructionReservedDriveCountCurrent() {
		return this.reconstructionReservedDriveCountCurrent;
	}
	/** @param x The reserved capacity that is currently available to hold rebuilt data (dynamic). If all of the reserved capacity is available, then this value will equal the reconstructionReservedDriveCount. */
	public void setReconstructionReservedDriveCountCurrent(int x) {
		this.reconstructionReservedDriveCountCurrent = x;
	}

	/** The pool utilization warning threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity. */
	@io.swagger.annotations.ApiModelProperty(value ="The pool utilization warning threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity." , required = true)
	@XmlElement(required = true)
	private int poolUtilizationWarningThreshold;

	/** @return The pool utilization warning threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity. */
	public int getPoolUtilizationWarningThreshold() {
		return this.poolUtilizationWarningThreshold;
	}
	/** @param x The pool utilization warning threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity. */
	public void setPoolUtilizationWarningThreshold(int x) {
		this.poolUtilizationWarningThreshold = x;
	}

	/** The pool utilization critical threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity. */
	@io.swagger.annotations.ApiModelProperty(value ="The pool utilization critical threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity." , required = true)
	@XmlElement(required = true)
	private int poolUtilizationCriticalThreshold;

	/** @return The pool utilization critical threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity. */
	public int getPoolUtilizationCriticalThreshold() {
		return this.poolUtilizationCriticalThreshold;
	}
	/** @param x The pool utilization critical threshold as a percentage of the total user configurable capacity. A MEL event is generated when the configured capacity exceeds the specified level of the configurable capacity. */
	public void setPoolUtilizationCriticalThreshold(int x) {
		this.poolUtilizationCriticalThreshold = x;
	}

	/** The Disk pool state set based on state of the threshold. */
	@io.swagger.annotations.ApiModelProperty(value ="The Disk pool state set based on state of the threshold." , required = true)
	@XmlElement(required = true)
	private DiskPoolUtilizationState poolUtilizationState = DiskPoolUtilizationState.__UNDEFINED;

	/** @return The Disk pool state set based on state of the threshold. */
	public DiskPoolUtilizationState getPoolUtilizationState() {
		return this.poolUtilizationState;
	}
	/** @param x The Disk pool state set based on state of the threshold. */
	public void setPoolUtilizationState(DiskPoolUtilizationState x) {
		this.poolUtilizationState = x;
	}

	/** This value identifies how much capacity (in bytes) is being wasted due to a mix of drive sizes. This value will be zero as long as the pool consists of like drive sizes. */
	@io.swagger.annotations.ApiModelProperty(value ="This value identifies how much capacity (in bytes) is being wasted due to a mix of drive sizes. This value will be zero as long as the pool consists of like drive sizes." , required = true)
	@XmlElement(required = true)
	private long unusableCapacity;

	/** @return This value identifies how much capacity (in bytes) is being wasted due to a mix of drive sizes. This value will be zero as long as the pool consists of like drive sizes. */
	public long getUnusableCapacity() {
		return this.unusableCapacity;
	}
	/** @param x This value identifies how much capacity (in bytes) is being wasted due to a mix of drive sizes. This value will be zero as long as the pool consists of like drive sizes. */
	public void setUnusableCapacity(long x) {
		this.unusableCapacity = x;
	}

	/** One failed drive degraded reconstruction priority. */
	@io.swagger.annotations.ApiModelProperty(value ="One failed drive degraded reconstruction priority." , required = true)
	@XmlElement(required = true)
	private DiskPoolOperationPriority degradedReconstructPriority = DiskPoolOperationPriority.__UNDEFINED;

	/** @return One failed drive degraded reconstruction priority. */
	public DiskPoolOperationPriority getDegradedReconstructPriority() {
		return this.degradedReconstructPriority;
	}
	/** @param x One failed drive degraded reconstruction priority. */
	public void setDegradedReconstructPriority(DiskPoolOperationPriority x) {
		this.degradedReconstructPriority = x;
	}

	/** Two failed drive reconstruction critical priority. */
	@io.swagger.annotations.ApiModelProperty(value ="Two failed drive reconstruction critical priority." , required = true)
	@XmlElement(required = true)
	private DiskPoolOperationPriority criticalReconstructPriority = DiskPoolOperationPriority.__UNDEFINED;

	/** @return Two failed drive reconstruction critical priority. */
	public DiskPoolOperationPriority getCriticalReconstructPriority() {
		return this.criticalReconstructPriority;
	}
	/** @param x Two failed drive reconstruction critical priority. */
	public void setCriticalReconstructPriority(DiskPoolOperationPriority x) {
		this.criticalReconstructPriority = x;
	}

	/** Priority of other background operations (DVE,DCE,DCR, and IAF). */
	@io.swagger.annotations.ApiModelProperty(value ="Priority of other background operations (DVE,DCE,DCR, and IAF)." , required = true)
	@XmlElement(required = true)
	private DiskPoolOperationPriority backgroundOperationPriority = DiskPoolOperationPriority.__UNDEFINED;

	/** @return Priority of other background operations (DVE,DCE,DCR, and IAF). */
	public DiskPoolOperationPriority getBackgroundOperationPriority() {
		return this.backgroundOperationPriority;
	}
	/** @param x Priority of other background operations (DVE,DCE,DCR, and IAF). */
	public void setBackgroundOperationPriority(DiskPoolOperationPriority x) {
		this.backgroundOperationPriority = x;
	}

	/** The allocation granularity (in bytes) for volumes in a disk pool. */
	@io.swagger.annotations.ApiModelProperty(value ="The allocation granularity (in bytes) for volumes in a disk pool." , required = true)
	@XmlElement(required = true)
	private long allocGranularity;

	/** @return The allocation granularity (in bytes) for volumes in a disk pool. */
	public long getAllocGranularity() {
		return this.allocGranularity;
	}
	/** @param x The allocation granularity (in bytes) for volumes in a disk pool. */
	public void setAllocGranularity(long x) {
		this.allocGranularity = x;
	}
}
