package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration object is used to specify the different categories of events that are tracked in the MEL. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(230)
public enum EventCategory implements Serializable {
		/** The MEL entry is associated with an error, either in internal logic or in a request from a client system. */
		error(1),
		/** The MEL entry is associated with a physical component failure. */
		failure(2),
		/** The MEL entry is associated with a command that was received from a host system, typically one issued to cause a configuration change. */
		command(3),
		/** The MEL entry is associated with a standard mechanism for notifying external agents of a configuration change. */
		notification(4),
		/** The MEL entry is associated with a change in the state of an internal component or element. */
		stateChange(5),
		/** The MEL entry was generated by a host system and stored by the controller. */
		hostEntry(6),
		/** The MEL entry does not fall into any of the previous categories. */
		general(7),
		__UNDEFINED(464378545);

		public final int value;

		private EventCategory(int v) {
			this.value = v;
		}
}
