package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration identifies the features that can be part of a feature bundle. A FeatureId is different from a Capability in that a FeatureId represents something that may or may not be presently enabled, while a Capability represents something that the array is capable of, i.e., something that is by definition enabled, */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(8)
public enum FeatureId implements Serializable {
		/** The feature is "VOLUMES PER_PARTITION". */
		volumesPerPartition(1),
		/** The feature is "TOTAL NUMBER OF VOLUMES" */
		totalNumberOfVolumes(2),
		/** The feature is "STORAGE PARTITIONS". */
		storagePartitions(3),
		/** The feature is "SNAPSHOT". */
		snapshot(4),
		/** The feature is "VOLUME COPY". */
		volumeCopy(5),
		/** The feature is "REMOTE MIRRORING". */
		remoteMirroring(6),
		/** The feature is "DRIVE TRAY EXPANSION". */
		driveTrayExpansion(7),
		/** The feature is "MIXED DRIVE TYPES". */
		mixedDriveTypes(8),
		/** The feature is "MANAGEMENT APPLICATION". Supported values for this feature conform to the MgmtApplicationType enumeration values, represented as character strings. */
		mgmtApplication(9),
		/** The feature is "SUPPORTED DRIVES". */
		supportedDrives(10),
		/** The feature is "SUPPORTED DRIVE TRAYS". */
		supportedDriveTrays(11),
		/** The feature is "PERFORMANCE TIER". */
		performanceTier(12),
		/** The feature is "TOTAL NUMBER OF SNAPSHOTS". */
		totalNumberOfSnapshots(13),
		/** The feature is "TOTAL NUMBER OF VOLUME COPY RELATIONSHIPS". */
		totalNumberOfVolCopies(14),
		/** The feature is "GOLD KEY". */
		goldKey(15),
		/** The feature is "SNAPSHOTS PER VOLUME". */
		snapshotsPerVolume(16),
		/** deprecated. */
		totalNumberOfMirrors(17),
		/** The feature is "RAID 6 VOLUME GROUPS". */
		raid6(18),
		/** The feature is "CONTROLLER STATE CAPTURE". */
		stateCapture(19),
		/** Deprecated. */
		sataStrLen(20),
		/** Secure Volume feature to support FDE drives. */
		secureVolume(21),
		/** T10 End to End Data Protection Information (PI) feature support. */
		protectionInformation(22),
		/** The Solid State Disk feature support. */
		solidStateDisk(23),
		/** The drive limit feature is supported. */
		driveSlotLimit(30),
		/** The FDE proxy key management feature is supported. */
		fdeProxyKeyManagement(31),
		/** The "Supported Interposer" feature is supported. */
		supportedInterposer(32),
		/** The Vendor Drive Slot feature is supported. */
		vendorSupportedDrives(38),
		/** The Flash Read Cache feature is supported. */
		flashReadCache(47),
		/** The feature id is Total Number of Async Mirror Groups. */
		totalNumberOfAsyncMirrorGroups(48),
		/** The Feature ID is Total Number of Async Mirrors Per Group */
		totalNumberOfAsyncMirrorsPerGroup(49),
		/** The Feature ID is Total Number of ARVM Mirrors Per Array. */
		totalNumberOfArvmMirrorsPerArray(50),
		/** The PiT Groups feature is supported. */
		totalNumberOfPitsPerArray(51),
		/** The Feature ID is PiT Groups Per Volume. */
		pitGroupsPerVolume(52),
		/** The Feature ID is Total Number of PiT Groups. */
		totalNumberOfPitGroups(53),
		/** The Feature ID is PiTs per PiT Group. */
		pitsPerPitGroup(54),
		/** The Feature ID is Member Vols Per PiT Consistency Group */
		memberVolsPerPitConsistencyGroup(55),
		/** The Feature ID is Total Number of PiT Consistency Groups */
		totalNumberOfPitConsistencyGroups(56),
		/** The Feature ID is Total Number of PiT Views. */
		totalNumberOfPitViews(57),
		/** The Feature ID is Total Number of Thin Volumes Per Array. */
		totalNumberOfThinVolumesPerArray(58),
		/** Native SATA drives are supported. */
		nativeSataDriveSupport(60),
		/** This id references the number of solid state disks allowed by the feature bundle data table (FBDT). */
		solidStateDiskLimit(61),
		/** Total number of mirrors (both sync and async/ARVM) allowed per array. */
		totalNumberOfRemoteMirrorsPerArray(62),
		/** The Autosupport feature is supported. */
		asup(63),
		/** This selects a field from the Feature Bundle Table that contains the filename of the MEL Event Configuration Table to load from flash. */
		ectSelector(64),
		/** The SNMP Object Identifier (OID) that forms the basis of the MIB sub-tree for the embedded SNMP agent is configurable on a per-sub-model basis. This SNMP OID is reported via GET requests for the sysObjectId variable in the MIB-II System Group. */
		embeddedSnmpOid(65),
		/** The Autosupport On Demand feature is supported. */
		asupOnDemand(66),
		/** DACStore Compatibility IDs are supported. */
		dacstoreCompatId(67),
		/** The Samoa host interface card is supported. */
		samoaHicProtocol(68),
		/** This is the feature that allows special Target Port LUN mapping to limit exposure of LUN to only one target port. */
		targetPortLunMapping(69),
		/** This feature ID sets the personality of any Hilda chips on a controller baseboard */
		hildaBaseboardProtocol(72),
		/** This feature ID sets the protocol of the Denali2 HIC card -- iSER or SRP. */
		denali2Protocol(73),
		__UNDEFINED(464378545);

		public final int value;

		private FeatureId(int v) {
			this.value = v;
		}
}
