package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration defines the different LUN mapping types that may be configured as part of the Storage Partitions feature. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(108)
public enum LUNMappingType implements Serializable {
		/** This value is reserved. */
		none(1),
		/** This value indicates that a LUN mapping is based on the host port from which the I/O request is generated. Such mappings are not supported in the current version of the controller firmware. */
		hostport(2),
		/** This value indicates that a LUN mapping is based on the host from which the I/O request is generated. */
		host(3),
		/** This value indicates that a LUN mapping is based on the cluster from which the I/O request is generated. */
		cluster(4),
		/** This value indicates that a LUN mapping is based on the storage array port at which the I/O request is received by the array controller. Such mappings are not supported in the current version of the controller firmware. */
		saport(5),
		/** This value indicates that a LUN mapping is based on the storage array port group at which the I/O request is received by the array controller. Such mappings are not supported in the current version of the controller firmware */
		saportgroup(6),
		/** This value indicates that a LUN mapping is based on the host-to-storage-array connection used to convey the I/O request to the array controller. Such mappings are not supported in the current version of the controller firmware. */
		hostsaconnection(7),
		/** This value indicates that a LUN mapping is part of the default mapping definition. */
		all(8),
		__UNDEFINED(464378545);

		public final int value;

		private LUNMappingType(int v) {
			this.value = v;
		}
}
