package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains all structural, state and configuration information for the storage array. It is returned to the client by the getObjectGraph procedure, which is the client's primary mechanism for determining the state and configuration of an array. The object bundle is returned as a "flat" structure, in that it contains a series of arrays of objects, with no explicit object linkage structure defined. The client can determine the linkages and relationships between the objects by inspecting the various reference fields within the objects. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1170)
public class ObjectBundle implements Serializable {
	public ObjectBundle() {
	}

	/** The configuration generation number that was in effect at the time this object bundle was constructed by the controller. The client can use this value to determine if it currently holds the latest version of the object graph. */
	@io.swagger.annotations.ApiModelProperty(value ="The configuration generation number that was in effect at the time this object bundle was constructed by the controller. The client can use this value to determine if it currently holds the latest version of the object graph." , required = true)
	@XmlElement(required = true)
	private long configGeneration;

	/** @return The configuration generation number that was in effect at the time this object bundle was constructed by the controller. The client can use this value to determine if it currently holds the latest version of the object graph. */
	public long getConfigGeneration() {
		return this.configGeneration;
	}
	/** @param x The configuration generation number that was in effect at the time this object bundle was constructed by the controller. The client can use this value to determine if it currently holds the latest version of the object graph. */
	public void setConfigGeneration(long x) {
		this.configGeneration = x;
	}

	/** A StorageArray object that contains base information about the storage array as a whole. */
	@io.swagger.annotations.ApiModelProperty(value ="A StorageArray object that contains base information about the storage array as a whole." , required = true)
	@XmlElement(required = true)
	private StorageArray sa;

	/** @return A StorageArray object that contains base information about the storage array as a whole. */
	public StorageArray getSa() {
		return this.sa;
	}
	/** @param x A StorageArray object that contains base information about the storage array as a whole. */
	public void setSa(StorageArray x) {
		this.sa = x;
	}

	/** A variable-length array of Tray structures. This array contains one element for each tray object that exists within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of Tray structures. This array contains one element for each tray object that exists within the storage array." , required = true)
	@XmlElement(required = true)
	private Tray[] tray;

	/** @return A variable-length array of Tray structures. This array contains one element for each tray object that exists within the storage array. */
	public Tray[] getTray() {
		return this.tray;
	}
	/** @param x A variable-length array of Tray structures. This array contains one element for each tray object that exists within the storage array. */
	public void setTray(Tray[] x) {
		this.tray = x;
	}

	/** A variable-length array of Component structures. This array contains one element for each physical component object that exists within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of Component structures. This array contains one element for each physical component object that exists within the storage array." , required = true)
	@XmlElement(required = true)
	private ComponentBundle componentBundle;

	/** @return A variable-length array of Component structures. This array contains one element for each physical component object that exists within the storage array. */
	public ComponentBundle getComponentBundle() {
		return this.componentBundle;
	}
	/** @param x A variable-length array of Component structures. This array contains one element for each physical component object that exists within the storage array. */
	public void setComponentBundle(ComponentBundle x) {
		this.componentBundle = x;
	}

	/** A variable-length array of Controller structures. This array contains one element for each RAID controller object that exists within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of Controller structures. This array contains one element for each RAID controller object that exists within the storage array." , required = true)
	@XmlElement(required = true)
	private Controller[] controller;

	/** @return A variable-length array of Controller structures. This array contains one element for each RAID controller object that exists within the storage array. */
	public Controller[] getController() {
		return this.controller;
	}
	/** @param x A variable-length array of Controller structures. This array contains one element for each RAID controller object that exists within the storage array. */
	public void setController(Controller[] x) {
		this.controller = x;
	}

	/** A variable-length array of Drive structures. This array contains one element for each physical disk drive object that exists within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of Drive structures. This array contains one element for each physical disk drive object that exists within the storage array." , required = true)
	@XmlElement(required = true)
	private Drive[] drive;

	/** @return A variable-length array of Drive structures. This array contains one element for each physical disk drive object that exists within the storage array. */
	public Drive[] getDrive() {
		return this.drive;
	}
	/** @param x A variable-length array of Drive structures. This array contains one element for each physical disk drive object that exists within the storage array. */
	public void setDrive(Drive[] x) {
		this.drive = x;
	}

	/** A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array." , required = true)
	@XmlElement(required = true)
	private VolumeGroup[] volumeGroup;

	/** @return A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array. */
	public VolumeGroup[] getVolumeGroup() {
		return this.volumeGroup;
	}
	/** @param x A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array. */
	public void setVolumeGroup(VolumeGroup[] x) {
		this.volumeGroup = x;
	}

	/** A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array." , required = true)
	@XmlElement(required = true)
	private Volume[] volume;

	/** @return A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array. */
	public Volume[] getVolume() {
		return this.volume;
	}
	/** @param x A variable-length array of VolumeGroup structures. This array contains one element for each volume group object that exists within the storage array. */
	public void setVolume(Volume[] x) {
		this.volume = x;
	}

	/** A variable-length array of FreeExtent structures. This array contains one element for each free extent object that exists within the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of FreeExtent structures. This array contains one element for each free extent object that exists within the storage array." , required = true)
	@XmlElement(required = true)
	private FreeExtent[] freeExtent;

	/** @return A variable-length array of FreeExtent structures. This array contains one element for each free extent object that exists within the storage array. */
	public FreeExtent[] getFreeExtent() {
		return this.freeExtent;
	}
	/** @param x A variable-length array of FreeExtent structures. This array contains one element for each free extent object that exists within the storage array. */
	public void setFreeExtent(FreeExtent[] x) {
		this.freeExtent = x;
	}

	/** A variable-length array of DVE structures. This array contains one element for each volume being expanded. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of DVE structures. This array contains one element for each volume being expanded." , required = true)
	@XmlElement(required = true)
	private DVEVolume[] dveVol;

	/** @return A variable-length array of DVE structures. This array contains one element for each volume being expanded. */
	public DVEVolume[] getDveVol() {
		return this.dveVol;
	}
	/** @param x A variable-length array of DVE structures. This array contains one element for each volume being expanded. */
	public void setDveVol(DVEVolume[] x) {
		this.dveVol = x;
	}

	/** An embedded object bundle that contains all configuration information relative to the "Storage Partitions" feature. */
	@io.swagger.annotations.ApiModelProperty(value ="An embedded object bundle that contains all configuration information relative to the \"Storage Partitions\" feature." , required = true)
	@XmlElement(required = true)
	private StoragePoolBundle storagePoolBundle;

	/** @return An embedded object bundle that contains all configuration information relative to the "Storage Partitions" feature. */
	public StoragePoolBundle getStoragePoolBundle() {
		return this.storagePoolBundle;
	}
	/** @param x An embedded object bundle that contains all configuration information relative to the "Storage Partitions" feature. */
	public void setStoragePoolBundle(StoragePoolBundle x) {
		this.storagePoolBundle = x;
	}

	/** An embedded object bundle that contains all the information relative to the Higher-Level Volumes. */
	@io.swagger.annotations.ApiModelProperty(value ="An embedded object bundle that contains all the information relative to the Higher-Level Volumes." , required = true)
	@XmlElement(required = true)
	private HLVolumeBundle highLevelVolBundle;

	/** @return An embedded object bundle that contains all the information relative to the Higher-Level Volumes. */
	public HLVolumeBundle getHighLevelVolBundle() {
		return this.highLevelVolBundle;
	}
	/** @param x An embedded object bundle that contains all the information relative to the Higher-Level Volumes. */
	public void setHighLevelVolBundle(HLVolumeBundle x) {
		this.highLevelVolBundle = x;
	}

	/** An embedded object bundle that contains all the information relative to missing volumes. */
	@io.swagger.annotations.ApiModelProperty(value ="An embedded object bundle that contains all the information relative to missing volumes." , required = true)
	@XmlElement(required = true)
	private GhostVolBundle ghostVolBundle;

	/** @return An embedded object bundle that contains all the information relative to missing volumes. */
	public GhostVolBundle getGhostVolBundle() {
		return this.ghostVolBundle;
	}
	/** @param x An embedded object bundle that contains all the information relative to missing volumes. */
	public void setGhostVolBundle(GhostVolBundle x) {
		this.ghostVolBundle = x;
	}

	/** Write consistency group bundle. */
	@io.swagger.annotations.ApiModelProperty(value ="Write consistency group bundle." , required = true)
	@XmlElement(required = true)
	private ConsistencyGroupBundle consistencyGroupBundle;

	/** @return Write consistency group bundle. */
	public ConsistencyGroupBundle getConsistencyGroupBundle() {
		return this.consistencyGroupBundle;
	}
	/** @param x Write consistency group bundle. */
	public void setConsistencyGroupBundle(ConsistencyGroupBundle x) {
		this.consistencyGroupBundle = x;
	}

	/** A variable-length array of IoInterface structures. This array contains one element for each I/O interface object that exists within the storage array */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of IoInterface structures. This array contains one element for each I/O interface object that exists within the storage array" , required = true)
	@XmlElement(required = true)
	private IoInterface[] ioInterface;

	/** @return A variable-length array of IoInterface structures. This array contains one element for each I/O interface object that exists within the storage array */
	public IoInterface[] getIoInterface() {
		return this.ioInterface;
	}
	/** @param x A variable-length array of IoInterface structures. This array contains one element for each I/O interface object that exists within the storage array */
	public void setIoInterface(IoInterface[] x) {
		this.ioInterface = x;
	}

	/** A variable-length array of NetworkInterface structures. This array contains one element for each network interface object that exists within the storage array */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length array of NetworkInterface structures. This array contains one element for each network interface object that exists within the storage array" , required = true)
	@XmlElement(required = true)
	private NetworkInterface[] networkInterface;

	/** @return A variable-length array of NetworkInterface structures. This array contains one element for each network interface object that exists within the storage array */
	public NetworkInterface[] getNetworkInterface() {
		return this.networkInterface;
	}
	/** @param x A variable-length array of NetworkInterface structures. This array contains one element for each network interface object that exists within the storage array */
	public void setNetworkInterface(NetworkInterface[] x) {
		this.networkInterface = x;
	}

	/** A variable length array of LockKeyID structures. Contains lock key information for the array. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable length array of LockKeyID structures. Contains lock key information for the array." , required = true)
	@XmlElement(required = true)
	private LockKeyID[] lockKeyIDs;

	/** @return A variable length array of LockKeyID structures. Contains lock key information for the array. */
	public LockKeyID[] getLockKeyIDs() {
		return this.lockKeyIDs;
	}
	/** @param x A variable length array of LockKeyID structures. Contains lock key information for the array. */
	public void setLockKeyIDs(LockKeyID[] x) {
		this.lockKeyIDs = x;
	}

	/** A variable length array of drive interposer data. An entry will appear in this array only if the interposerPresent field in the corresponding Drive structure is set to True. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable length array of drive interposer data. An entry will appear in this array only if the interposerPresent field in the corresponding Drive structure is set to True." , required = true)
	@XmlElement(required = true)
	private Interposer[] interposer;

	/** @return A variable length array of drive interposer data. An entry will appear in this array only if the interposerPresent field in the corresponding Drive structure is set to True. */
	public Interposer[] getInterposer() {
		return this.interposer;
	}
	/** @param x A variable length array of drive interposer data. An entry will appear in this array only if the interposerPresent field in the corresponding Drive structure is set to True. */
	public void setInterposer(Interposer[] x) {
		this.interposer = x;
	}

	/** This is a list of structures that provides a mapping from I/O interfaces to their associated HICs. */
	@io.swagger.annotations.ApiModelProperty(value ="This is a list of structures that provides a mapping from I/O interfaces to their associated HICs." , required = true)
	@XmlElement(required = true)
	private IoInterfaceHicMap[] ioInterfaceHicMap;

	/** @return This is a list of structures that provides a mapping from I/O interfaces to their associated HICs. */
	public IoInterfaceHicMap[] getIoInterfaceHicMap() {
		return this.ioInterfaceHicMap;
	}
	/** @param x This is a list of structures that provides a mapping from I/O interfaces to their associated HICs. */
	public void setIoInterfaceHicMap(IoInterfaceHicMap[] x) {
		this.ioInterfaceHicMap = x;
	}

	/** A list of current schedules. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of current schedules." , required = true)
	@XmlElement(required = true)
	private ScheduleInstance[] schedule;

	/** @return A list of current schedules. */
	public ScheduleInstance[] getSchedule() {
		return this.schedule;
	}
	/** @param x A list of current schedules. */
	public void setSchedule(ScheduleInstance[] x) {
		this.schedule = x;
	}

	/** This is a list of remote arrays which this array has visibility to for monitoring. */
	@io.swagger.annotations.ApiModelProperty(value ="This is a list of remote arrays which this array has visibility to for monitoring." , required = true)
	@XmlElement(required = true)
	private RemoteArray[] remoteArray;

	/** @return This is a list of remote arrays which this array has visibility to for monitoring. */
	public RemoteArray[] getRemoteArray() {
		return this.remoteArray;
	}
	/** @param x This is a list of remote arrays which this array has visibility to for monitoring. */
	public void setRemoteArray(RemoteArray[] x) {
		this.remoteArray = x;
	}

	/** An embedded object bundle that contains all of the information related to flash cache objects. */
	@io.swagger.annotations.ApiModelProperty(value ="An embedded object bundle that contains all of the information related to flash cache objects." , required = true)
	@XmlElement(required = true)
	private FlashCacheBundle flashCacheBundle;

	/** @return An embedded object bundle that contains all of the information related to flash cache objects. */
	public FlashCacheBundle getFlashCacheBundle() {
		return this.flashCacheBundle;
	}
	/** @param x An embedded object bundle that contains all of the information related to flash cache objects. */
	public void setFlashCacheBundle(FlashCacheBundle x) {
		this.flashCacheBundle = x;
	}

	/** SNMP-related objects */
	@io.swagger.annotations.ApiModelProperty(value ="SNMP-related objects" , required = true)
	@XmlElement(required = true)
	private SNMPAgentBundle snmpBundle;

	/** @return SNMP-related objects */
	public SNMPAgentBundle getSnmpBundle() {
		return this.snmpBundle;
	}
	/** @param x SNMP-related objects */
	public void setSnmpBundle(SNMPAgentBundle x) {
		this.snmpBundle = x;
	}

	/** This reports the key-value pairs and their references, and the mappings between Volumes and these key-value pairs. The data is used by the application and is opaque to the CFW. */
	@io.swagger.annotations.ApiModelProperty(value ="This reports the key-value pairs and their references, and the mappings between Volumes and these key-value pairs. The data is used by the application and is opaque to the CFW." , required = true)
	@XmlElement(required = true)
	private ApplicationAwarenessBundle applicationAwarenessBundle;

	/** @return This reports the key-value pairs and their references, and the mappings between Volumes and these key-value pairs. The data is used by the application and is opaque to the CFW. */
	public ApplicationAwarenessBundle getApplicationAwarenessBundle() {
		return this.applicationAwarenessBundle;
	}
	/** @param x This reports the key-value pairs and their references, and the mappings between Volumes and these key-value pairs. The data is used by the application and is opaque to the CFW. */
	public void setApplicationAwarenessBundle(ApplicationAwarenessBundle x) {
		this.applicationAwarenessBundle = x;
	}
}
