package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration defines the different recovery failure types that may be reported by a controller as part of the getRecoveryFailureList procedure. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(137)
public enum RecoveryFailureType implements Serializable {
		/** The failure type is Unknown. */
		unknownFailure(0),
		/** A fan component has failed. */
		failedFan(1),
		/** A power supply component has failed. */
		failedPowerSupply(2),
		/** A Fibre Channel minihub component has failed. */
		failedMinihub(3),
		/** An enclosure services module (ESM) component has failed. */
		failedEsm(4),
		/** A cache holdup battery is nearing its expiration date and needs to be replaced. */
		batteryNearExpiration(5),
		/** A battery has failed. */
		failedBattery(6),
		/** This recovery failure type indicates that the controller has detected that a temperature sensor has transitioned to a warning status. */
		nominalTempExceeded(7),
		/** The failure type is Max Temperature Exceeded. */
		maxTempExceeded(8),
		/** The failure type is UPS On Battery */
		upsOnBattery(9),
		/** The failure type is Non Preferred Path. */
		nonPreferredPath(10),
		/** The failure type is Memory Parity Error. */
		memParityError(11),
		/** A controller has experienced a drive-side I/O channel failure. */
		failedDriveScsiChannel(12),
		/** A volume group has transitioned to the degraded state due to one or more drive failures. */
		degradedVolume(13),
		/** A volume group has been marked failed due to an interrupted write condition. */
		failedVolumeInterruptedWrite(14),
		/** A volume group has failed during a modification operation, such as dynamic capacity expansion, RAID level migration, etc. */
		failedModifyingVolume(15),
		/** A volume group has failed during a modification operation, such as dynamic capacity expansion, RAID level migration, etc. This failure code is used for volume groups containing volumes with different RAID levels. It is not supported in the current release of the firmware. */
		failedModifyingMultiRaid(16),
		/** A volume group has been marked failed due to excessive drive failures. */
		failedVolume(17),
		/** A volume group has been marked failed due to excessive drive failures. This failure code is used for volume groups containing volumes with different RAID levels. It is not supported in the current release of the firmware. */
		failedVolumeMultiRaid(18),
		/** The failure type is Impaired Volume. */
		impairedVolume(19),
		/** A volume group was failed due to excessive drive failures, but has since had all failed drives replaced. Since the volumes within the volume group are no longer usable, they must all be formatted/initialized to make them usable again. */
		failedVolumeAwaitingInit(20),
		/** The failure type is Volume Hot Spare In Use */
		volumeHotSpareInUse(21),
		/** The failure type is Offline Volume Group. */
		offlineVolumeGroup(22),
		/** A drive has failed. */
		failedDrive(23),
		/** The failure type is Impending Drive Failure Risk - High. */
		impendingDriveFailureRiskHigh(24),
		/** The failure type is Impending Drive Failure Risk - Medium. */
		impendingDriveFailureRiskMed(25),
		/** The failure type is Impending Drive Failure Risk - Low. */
		impendingDriveFailureRiskLow(26),
		/** The failure type is Uncertified Drive */
		uncertifiedDrive(27),
		/** The failure type is Offline Controller. */
		offlineCtl(28),
		/** This Recovery Failure Type is logged when the controller is placed into Service Mode. */
		passiveCtl(29),
		/** This is obsolete. */
		partitionsNotCompliant(30),
		/** The firmware versions for the ESM cards in a tray do not match. */
		esmCodeVersionMismatch(31),
		/** The failure type is Lost Redundancy Drive. */
		lostRedundancyDrive(32),
		/** The failure type is Lost Redundancy Tray. */
		lostRedundancyTray(33),
		/** The failure type is Lost Redundancy ESM. */
		lostRedundancyEsm(34),
		/** The failure type is Tray ID Mismatch */
		trayidMismatch(35),
		/** The failure type is Tray ID Conflict */
		trayidConflict(36),
		/** A transceiver module (GBIC or SFP) has failed. */
		failedTransceiverModule(37),
		/** The drive side fibre channel ports have been incorrectly connected. */
		channelMiswire(38),
		/** This is obsolete. */
		nonFruBatteryNearExpiration(39),
		/** This is obsolete. */
		nonFruFailedBattery(40),
		/** The failure type is RPA_ERR_CTL. */
		rpaErrCtl(41),
		/** The failure type is Repository Over Threshold. */
		repositoryOverThreshold(42),
		/** The failure type is Repository Full. */
		repositoryFull(43),
		/** The failure type is Snapshot Failed. */
		snapshotFailed(44),
		/** The failure type is Unsupported Minihub. */
		unsupportedMinihub(45),
		/** An ESM miswire has occurred. */
		esmMiswire(46),
		/** A volume is missing. */
		ghostVolume(47),
		/** The failure type is Snapshot Not Compliant */
		snapshotNotCompliant(48),
		/** The failure type is RVM Not Compliant. */
		rvmNotCompliant(49),
		/** The failure type is Metadata Offline. */
		metadataOffline(50),
		/** The failure type is Mirror Dual Primary. */
		mirrorDualPrimary(51),
		/** The failure type is Mirror Dual Secondary. */
		mirrorDualSecondary(52),
		/** The failure type is Mirror Unsynchronized. */
		mirrorUnsynchronized(53),
		/** The failure type is Remote No LUN. */
		remoteNoLun(54),
		/** The failure type is Remote No Array. */
		remoteNoArray(55),
		/** The failure type is Remote No Fabric. */
		remoteNoFabric(56),
		/** The failure type is Remote WWN Change Failed. */
		remoteWwnChangeFailed(57),
		/** One or both of the controllers in this storage array cannot communicate with the fan. This problem typically occurs when a component is removed that the controllers need to gain information about other components. */
		fanUnknownStat(58),
		/** The failure type is Power Supply Unknown Status. */
		powerSupplyUnknownStat(59),
		/** One or both of the controllers in this storage array cannot communicate with the ESM. This problem typically occurs when a component is removed that the controllers need to gain information about other components. */
		esmUnknownStat(60),
		/** The failure type is Temp Sensor Unknown Stat */
		tempSensorUnknownStat(61),
		/** This is obsolete. */
		transModUnknownStat(62),
		/** A drive has been bypassed due to a speed mismatch. */
		driveBypassedSpeedMismatch(63),
		/** A drive has been bypassed and the cause is unknown. */
		driveBypassedCauseUnknown(64),
		/** The failure type is Minihub Speed Mismatch. */
		minihubSpeedMismatch(65),
		/** The failure type is Removed ESM. */
		removedEsm(66),
		/** The failure type is Removed Battery. */
		removedBattery(67),
		/** This is obsolete. */
		nonFruRemovedBattery(68),
		/** The failure type is Volume Copy Failed. */
		volcopyFailed(69),
		/** The failure type is Volume Copy Not Compliant. */
		volcopyNotCompliant(70),
		/** A degraded drive channel condition has occurred. */
		channelDegraded(71),
		/** The failure type is Unsupported Tray. */
		unsupportedTray(72),
		/** The failure type is Speed Neg Error */
		speedNegError(73),
		/** The failure type is USM Database Full */
		usmDatabaseFull(74),
		/** The failure type is USM Unreadable Sectors Exist */
		usmUnreadableSectorsExist(75),
		/** The failure type is Path Degraded. */
		pathDegraded(76),
		/** Yuma 1.4 */
		netSetupError(77),
		/** The failure type is Mismatched Drive Type. */
		mismatchedDriveType(78),
		/** One of the controllers in this storage array is incompatible with the other controller. The alternate controller is locked down. */
		ctlMismatch(79),
		/** A failure of a discrete line has been detected. */
		failedDiscreteLine(80),
		/** A failed drive channel condition has occurred. */
		channelFailed(81),
		/** The failure type is Link Speed Detection Mismatch. */
		linkSpeedDetectionMismatch(82),
		/** The failure type is Uncertified ESM */
		uncertifiedEsm(83),
		/** The failure type is Removed Fan. */
		removedFan(84),
		/** The failure type is Removed Power Supply. */
		removedPowerSupply(85),
		/** The failure type is Removed Temp Sensor. */
		removedTempSensor(86),
		/** The failure type is Removed Interconnect CRU. */
		removedIccCru(87),
		/** The failure type is Removed Support CRU. */
		removedSupportCru(88),
		/** The Interconnect CRU (also known as an Interconnect-battery canister) for this storage array has failed */
		failedIccCru(89),
		/** A support CRU (also called a Power-Fan canister) has failed and must be replaced. */
		failedSupportCru(90),
		/** One or both of the controllers in this storage array cannot communicate with the storage array component listed in the Details area. This problem typically occurs when a component is removed that the controllers need to gain information about other components. */
		batteryUnknownStat(91),
		/** There are drive trays in the storage array that are not cabled correctly because they have ESM canisters that must be cabled sequentially together. */
		driveTraysNotGroupedTogether(92),
		/** This failure type is obsolete. */
		goldKeyNotCompliant(93),
		/** This is obsolete. */
		mismatchedMdtSettings(94),
		/** This is obsolete. */
		mismatchedGoldKeySettings(95),
		/** A controller has multiple connections from its drive ports to ESM canisters in the same drive tray. */
		ctlMiswire(96),
		/** The failure type is Support CRU No Input */
		supportCruNoinput(97),
		/** The failure type is Submodel Not Supported */
		submodelNotSupported(98),
		/** The failure type is Submodel Not Set */
		submodelNotSet(99),
		/** The failure type is Submodel Mismatch */
		submodelMismatch(100),
		/** A battery pack in the Interconnect CRU has failed. In rare cases, this problem could also result from a failure in the battery system, which includes charging units and voltage regulators. */
		failedBatterySystem(101),
		/** The failure type is Removed Battery Pack. */
		removedBatteryPack(102),
		/** A battery is physically present when the storage array is configured to operate without batteries. */
		batteryConfigMismatch(103),
		/** The ESM cards in a tray do not match. */
		esmHardwareMismatch(104),
		/** The failure type is host-board related. */
		hostBoardFault(105),
		/** The array has captured diagnostic data for an abnormal event. */
		ddcAvailable(106),
		/** The failure type is Replace Drive Wrong Type. */
		replacedDriveWrongType(107),
		/** A support CRU is configured incorrectly - it is missing a power supply that is needed in order to meet the system's redundancy requirements */
		redundantPsRequired(108),
		/** The number of drive trays in the storage array exceeds the limit for the particular product. */
		driveTraysNotCompliant(109),
		/** More SAS devices have been discovered than can be successfully addressed by the RAIDcontroller. */
		sasDeviceLimitExceeded(110),
		/** This value of the enumeration represents a SAS miswire condition where a controller host port is connected to an expansion drive tray, instead of a host. */
		sasPortMiswired(111),
		/** This value of the enumeration means that a degraded SAS port exists in the array. */
		sasPortDegraded(112),
		/** This value of the enumeration means that a failed SAS port exists in the array. */
		sasPortFailed(113),
		/** The contents of a Storage Bridge Bay (SBB) EEPROM, used for vital product data storage, has become corrupted. */
		corruptVpdEeprom(114),
		/** An I2C bus connected to one of the Storage Bridge Bay (SBB) EEPROMs has failed. */
		failedI2cBus(115),
		/** The enclosure has invalid configuration settings. */
		enclosureMisconfigured(117),
		/** The storage array has been found to have attributes that violate the current sub-model definition. */
		featureBundleNotCompliant(118),
		/** A drive has been bypassed on only one of its ports. */
		driveBypassedSinglePort(119),
		/** The two ESMs in a tray are reporting different version information for the ESM factory default settings. */
		esmFactoryDefaultsMismatch(120),
		/** The status of a host board cannot be determined because communication pathways on which the controller(s) depend to get that information are not available. The alternate controller is locked down. */
		hostBoardUnknownStat(121),
		/** A host I/O card has failed and the alternate controller is locked down. This enumeration value is numerically equivalent to REC_HOST_BOARD_FAULT. It has been added so as to make the failure recovery terminology line up with the major event log terminology. The two enumeration values may be used interchangeably. */
		failedHostIoCard(150),
		/** The capacity of a smart battery unit is insufficient to hold up the cache for a set period of time, depending on the type of battery. */
		batteryWarn(176),
		/** A volume group has transitioned from the online to the partial state because of a drive removal.The partial state means that, while some drives are missing, there is a sufficient number left to make volume data accessible. */
		volumeGroupPartiallyComplete(200),
		/** A volume group has transitioned from the online state to the incomplete state because of a drive removal. The incomplete state means that the group does not have enough drives to make volume data accessible. */
		volumeGroupIncomplete(201),
		/** A volume group has transitioned from the online or incomplete state to the missing state because of drive removal. The missing state means that all drives of the group are missing. */
		volumeGroupMissing(202),
		/** A drive designated as a standby hot spare is missing from the configuration. */
		hotspareDriveMissing(203),
		/** A drive has a DACStore that is unrecognizable because it was written by a later version of the firmware. */
		driveIncompatibleUprevDacstore(204),
		/** A drive has a DACStore that is unrecognizable because it was written by an earlier version of the firmware. */
		driveIncompatibleDownrevDacstore(205),
		/** A controllers in this storage array cannot communicate with the interconnect CRU. This problem typically occurs when a component is removed that the controllers need to gain information about other components. The alternate controller is locked down. */
		iccCruUnknownStat(206),
		/** The alarm was removed. */
		removedAlarm(207),
		/** One or both of the controllers in this storage array cannot communicate with a support CRU. This problem typically occurs when a component is removed that the controllers need to gain information about other components. */
		supportCruUnknownStat(208),
		/** The performance tiering feature is out-of-compliance. */
		performanceTierNotCompliant(209),
		/** A RAID 6 SAFE key has been imported to the storage array on a set of foreign drives, and the storage array is now out of compliance; or the RAID 6 SAFE key has been removed, and there are still RAID 6 volume groups present in the storage array (i.e., "not within limits"). */
		raid6NotCompliant(210),
		/** A drive has a formatted sector size that is different from the other drives in the storage array. */
		driveIncompatibleSectorSize(211),
		/** The configuration data stored on a foreign drive indicates that it is part of a volume group in the same storage array; however, the drive's configuration data is inconsistent with that of the volume group in one of the following ways: (1) the volume group is in the complete state and has no indication of drives missing, or (2) the volume group is in the exported state, but the drive's configuration data is older than that of the volume group's drives. */
		foreignDriveInconsistent(212),
		/** The volume group information on an incoming foreign drive refers to a native drive in the storage array as being a member of the group. */
		foreignDriveRefersToNativeDrive(213),
		/** A volume group in the partial state along with its missing drive are present in the same storage array, however their respective metadata are in conflict, making it impossible to complete the volume group. */
		nativeVgRefersToForeignDrive(214),
		/** A volume group in the partial state along with its missing drive are present in the same storage array. Their respective metadata are in agreement with respect to volume group membership; however, the storage array considers the volume group as native and the drive as foreign. */
		nativeVgForeignDriveMutualRef(215),
		/** The drives for a volume group that were removed from an array with no export performed, have been re-inserted back into that array, after having been imported into another array where the volume group's configuration was changed in various ways. */
		vgCloned(216),
		/** A contingent volume group refers to a foreign drive in the storage array which has an inconsistent configuration database. */
		foreignDriveHasInconsistentRole(217),
		/** A partial volume group refers to a foreign drive in the storage array; a foreign volume group refers to the same drive; and the foreign drive considers itself assigned to the foreign volume group. */
		vgDrivePartOfMultipleVgs(218),
		/** A legacy (REV3) volume group which contains an in-use hot spare and/or a failed drive is inserted. */
		incompatibleFailedLegacyDrive(220),
		/** The controller is configured with an unsupported cache memory size. */
		unsupportedCacheMemorySize(223),
		/** A channel (or channels) dedicated to cache mirroring has (have) failed. The root cause is a degraded controller. */
		dedicatedMirrorChannelFailed(224),
		/** A partial volume group refers to a foreign drive in the storage array; a foreign volume group refers to the same drive; and the foreign drive considers itself assigned to the foreign volume group. */
		vgHasDrivePartOfMultipleVgs(225),
		/** A drive in the array has a SNIA Disk Data Format (DDF) anchor header with a T10 vendor ID other than LSI-Engenio */
		ddfDriveOtherVendor(226),
		/** The storage array has detected the presence of multiple configuration databases among the drives it is trying to adopt. Since the array can't determine which drive to adopt, all drives of the array are locked out. */
		multipleConfigDatabasesDetected(227),
		/** A configuration database adoption process failed due to incoming drives having an unsupported RAID level. All drives of the array locked out when this happens. */
		adoptionFailedRaidLevelUnsupported(228),
		/** A database adoption failed because a hard limit was exceeded. All drives of the array are locked out when this happens. */
		dbAdoptionHardLimitExceeded(229),
		/** A legacy volume group has been inserted into a storage array which has failed drives and/or in usehot-spares. */
		legacyVgNotOptimal(230),
		/** The two controllers in the storage array have different cache memory capacities. */
		cacheMemSizeMismatch(231),
		/** Emerald */
		altCtlrBoardIdUnreadable(250),
		/** A cache backup device has failed. */
		cacheBackupDeviceFailed(251),
		/** A cache backup device has its write-protect setting enabled. */
		cacheBackupDeviceWriteProtected(252),
		/** A cache backup device is missing, leaving insufficient space to perform a full backup. */
		cacheBackupDeviceInsufficientCapacity(253),
		/** A cache holdup battery has expired. */
		expiredBattery(254),
		/** A cache holdup battery inside the controller cannister has expired. */
		expiredIntegratedBattery(255),
		/** The failure type is Proc Memory Too Small for Cache. This will only occur in rare cases where not enough procedure memory was allocated to support the size of the rpa region. */
		procMemTooSmallForCache(259),
		/** The failure type is Battery Overtemp. */
		batteryOvertemp(261),
		/** A host type index is invalid with respect to the currently-running version of controller firmware. This problem may apply to either the default host type or to a particular host in the defined topology. */
		invalidHostTypeIndex(263),
		/** Insufficient processor memory */
		insufficientProcMemory(264),
		/** Cache backup device diagnostic test failed. */
		ctlFailedCacheBackupDev(265),
		/** Controller removed from array configured to use dual controllers. */
		removedController(266),
		/** A host board (a.k.a. host I/O card) has become degraded. A host board is considered degraded when some, but not all, of its ports are operational. */
		degradedHostIoCard(300),
		/** The failure type is LD FW Version Mismatch. */
		ldFwVersionMismatch(301),
		/** The failure type is LD Incompatible Database. */
		ldIncompatibleDatabase(302),
		/** The failure type is a host board ID mismatch. */
		hostBoardIdMismatch(325),
		/** The failure type is Interconnect CRU Missing. */
		iccMissing(326),
		/** The failure type is Link Speed Mismatch. */
		linkSpeedMismatch(327),
		/** The failure type is Unsupported Host Board. */
		unsupportedHostBoard(328),
		/** Write-back caching for one or more volumes has been forcibly disabled by the storage array. */
		writebackCachingDisabled(329),
		/** The array needs a lock key. */
		securityGetKey(331),
		/** The array lock keys for the controllers are different. */
		securityKeyInconsistent(333),
		/** The Secure Volume SAFE key has been removed and there are still Secure Volume groups present in the storage array. */
		securityNotCompliant(334),
		/** One or more drive channels have an unsupported combination of drive enclosures. */
		mixedDriveEnclosureMiswire(335),
		/** Obsolete. Unsuccessful isolation of redundancy mismatch. */
		unsuccessIsolationRedunMismatch(336),
		/** Obsolete. Drive PFA threshold exceeded but redundancy mismatch successfully isolated and corrected. */
		thresExcdedMismatchCorrected(337),
		/** The Host Context Agent (HCA) attempted to register a host port associated with a host that already has storage partition mappings. The host port was consequently marked inactive and can be activated through the storage management software or CLI. */
		inactiveHostPort(338),
		/** The Host Context Agent (HCA) attempted to register an iSCSI initiator associated with a host that already has storage partition mappings. The iSCSI initiator was consequently marked inactive and can be activated through the storage management software or CLI. */
		inactiveInitiator(339),
		/** The T10 Protection Information feature is out of compliance. */
		protectionInformationNotCompliant(340),
		/** The volume group has one or more protected volumes that cannot be supported by this storage array. */
		protectionInformationNotSupported(341),
		/** The inserted drive does not have sufficient capacity for the user data of the failed drive. */
		replacedInsufficientDriveCapacity(342),
		/** Drawer DCM or interposer failed. */
		drawerFailed(343),
		/** Drawer open or removed - could lead to enclosure overtemp condition. */
		drawerOpened(344),
		/** SSD feature out of compliance. */
		ssdNotCompliant(347),
		/** SSD at end of wear life. */
		ssdAtEndOfLife(349),
		/** Two ESMs or a controller and ESM are not cabled together properly. */
		fibreTrunkMiswire(364),
		/** The ESM does not support trunking. */
		fibreTrunkIncompatibleEsm(365),
		/** Number of discovered drive slots exceeds maximum for SubModel/Key. */
		driveSlotLimitNotCompliant(368),
		/** Using a Key Management Server and array needs a new key. */
		securityGetNewKey(370),
		/** Array in Key Needed state, no external KM SAFE key, and key request satisfied through installLockKey. Needs Attention condition cleared by applying appropriate SAFE key or through feature bundle migration. */
		externalKmsNotCompliant(371),
		/** Enclosure SIM failed validation. */
		sbbValidationFailure(374),
		/** The controller has detected an invalid power supply for the enclosure on start up or hot swap. */
		invalidPowerSupply(376),
		/** Enclosure power-down in progress due to an over-temperature or under-temperature threshold condition. */
		enclosureThermalShutdown(377),
		/** Write-Back Caching forcibly disabled. */
		wbCachingForciblyDisabled(378),
		/** A drive has an unsupported protocol connection. */
		driveUnsupportedProtocolConnection(379),
		/** TWI bus has failed. */
		failedTwiBus(380),
		/** Mismatched midplane EEPROM contents. */
		mismatchedMidplaneEeproms(381),
		/** The drive capacity is not supported. */
		driveUnsupportedCapacity(384),
		/** The evaluation license is about to expire. */
		evaluationLicenseExpirationImminent(385),
		/** Obsolete. Key ID is correct but the lock key is invalid. */
		externalKmsKeyInvalid(386),
		/** Multiple drive Lock Key IDs do not match the array Lock Key ID. */
		multipleMismatchedKeyIdsFound(387),
		/** Too many key validation attempts have failed. Clear by restarting array. */
		securityKeyValidationLock(388),
		/** Data in cache lost after power cycle or reset. Controller was unable to recover cache data. */
		cacheDataLoss(389),
		/** One of the base controller diagnostic tests has failed due to one or more of the components within the base controller not functioning as desired. */
		baseControllerDiagFailed(390),
		/** The premium feature is out of compliance. */
		featureNotCompliant(391),
		/** The drive has an incompatible Protection Information type. */
		driveIncompatiblePiType(392),
		/** A DCM has failed and the drawer is degraded. I/Os for the drawer may still be serviced through the alternate DCM. */
		drawerDegraded(393),
		/** The alternate controller is in a lockdown state as a result of an IOC diagnostic failure. */
		offlineCtlIocFail(394),
		/** The SATA flash drive configuration is invalid. */
		invalidSataFlashConfiguration(395),
		/** The controller has failed IOC diagnostic testing. */
		iocDiagFail(396),
		/** The wide port between the IOC and the local expander has had a phy disabled resulting in a degraded channel. */
		sasPhyDisabledLocalWidePortDegraded(397),
		/** The wide port between the IOC and the alternate's expander has had a phy disabled resulting in a degraded channel. */
		sasPhyDisabledSharedWidePortDegraded(398),
		/** A drawer is invalid and cannot be supported. */
		drawerInvalid(399),
		/** A drawer has been removed. This could lead to an overtemp condition in the enclosure. */
		drawerRemoved(400),
		/** A drive has an unsupported interposer firmware version. */
		driveUnsupportedInterposerFwVersion(401),
		/** A redundancy group has been determined to be inconsistent during a reconfiguration operation. After the reconfiguration completes the data will be consistent, but may be corrupt. */
		redundancyGroupNotConsistentDuringReconfig(402),
		/** A snapshot rollback operation has paused active data copy. */
		snapshotRollbackPaused(403),
		/** A PiT rollback operation has paused active data copy. */
		pitRollbackPaused(404),
		/** PiT Group repository capacity utilized exceeded warning threshold. */
		pitGroupRepositoryOverThreshold(405),
		/** PiT view repository capacity utilized exceeded warning threshold. */
		pitViewRepositoryOverThreshold(406),
		/** PiT Group repository full. */
		pitGroupRepositoryFull(407),
		/** PiT view repository full. */
		pitViewRepositoryFull(408),
		/** PiT group in failed state. */
		pitGroupFailed(409),
		/** PiT view in failed state. */
		pitViewFailed(410),
		/** PiT purged to free PiT group repository capacity. */
		pitPurged(411),
		/** An Async Mirror Group has been or still is in a degraded state. Note this is a "sticky" condition until the user acknowledges it via clearAsyncMirrorGroupFaultIndication. */
		arvmDegradedMirrorGroup(412),
		/** An Async Mirror is in failed state. */
		arvmFailedMirror(413),
		/** One or more Async Mirror Group members sync interval time exceeded the warning threshold. Note this is a "sticky" condition until the user acknowledges it via clearAsyncMirrorGroupFaultIndication. */
		arvmSyncIntervalTimeOverThreshold(414),
		/** Repository utilization for a specific Async Mirror Group member has exceeded the warning threshold. Note this is a "sticky" condition until the user acknowledges it via clearAsyncMirrorGroupMemberFaultIndication */
		arvmRepositoryOverWarnThreshold(415),
		/** Two arrays have conflicting Async Mirror Group roles. */
		arvmMirrorGroupRoleConflict(416),
		/** An unsecure data replica exists in the Volume Group (PiT View Repository, PiT Group Repository, Async Mirror Repository, or Async Mirror Secondary Volume). */
		incompatibleVolumeGroupSecurity(417),
		/** An Async Mirror Group deletion has partially failed, resulting in an orphaned mirror member. */
		arvmOrphanGroup(418),
		/** An Async Mirror Group member deletion has partially failed, resulting in an orphaned mirror member. */
		arvmOrphanMember(419),
		/** A recovery point is no longer available for a given Async Mirror Group. */
		arvmMirrorGroupRecoveryPointLost(420),
		/** A disk pool transitioned from the Complete state to the Partial state because of a drive removal. */
		diskPoolPartiallyPresent(421),
		/** A disk pool transitioned from the Complete state or the Partial state to the Incomplete state because of a drive removal. The pool is no longer accessible. */
		diskPoolIncomplete(422),
		/** A disk pool transitioned to the Missing state because of drive removal. */
		diskPoolMissing(423),
		/** The space reserved for reconstructions within a disk pool fell below the reconstruction reserved disk count value. This occurs when failed drives are rebuilt and use up reserved space. */
		diskPoolReconstructionDriveCountBelowThreshold(424),
		/** A disk pool utilization exceeds the Utilization Threshold Warning attribute. */
		diskPoolUtilizationWarning(425),
		/** A disk pool utilization exceeds the Utilization Threshold Critical attribute. */
		diskPoolUtilizationCritical(426),
		/** A Pending PiT Creation for a PiT Group failed. */
		pendingPitCreationFailed(427),
		/** A Pending PiT Creation for a Consistency Group failed. */
		pendingCgpitCreationFailed(428),
		/** The thin volume's repository is over the threshold value. */
		tpvRepositoryOverThreshold(429),
		/** The thin volume's repository is full. */
		tpvRepositoryFull(430),
		/** The thin volume is in a failed state. */
		tpvFailed(431),
		/** Repository utilization for a specific Async Mirror Group member has reached the full point (secondary repository). */
		arvmSecondaryRepositoryFull(432),
		/** Synchronization has been suspended by the controller due to an error condition (not due to a user request to suspend). */
		arvmSyncInternallySuspended(433),
		/** The Stable Store Backup database is in recovery mode. */
		databaseRecoveryMode(434),
		/** Repository utilization for a specific Async Mirror Group Member (primary) has reached the full point. Note this is a "sticky" recovery action. */
		arvmPrimaryRepositoryFull(435),
		/** A SATA drive is incompatible because it does not support SMART Command Transfer (SCT) commands. */
		incompatibleSataDrive(436),
		/** A Disk Pool's capacity is depleted.. */
		diskPoolCapacityDepleted(437),
		/** The drive is unsupported based on the model number. */
		driveIncompatibleModelNumberUnsupported(438),
		/** Flash Cache is in non-optimal state due to missing or inaccessible drives. */
		flashCacheNonOptimalDrives(439),
		/** Flash Cache is in non-optimal condition due to hot spare in use. */
		flashCacheHotSpareInUse(440),
		/** In a Native SATA array this indicates the controller has a duplex NVSRAM setting and all drives appear as bypassed. */
		allDrivesBypassedIncompatibleNvsram(441),
		/** A drive in a Disk Pool has failed. */
		diskPoolDriveFailure(443),
		/** Access to disk pool volumes is prohibited because of insufficient memory. */
		diskPoolInsufficientMemory(444),
		/** An orphan Async Mirror Group Incomplete Member exists. */
		arvmOrphanIncompleteMember(445),
		/** Synchronization has been paused by the controller due to the state of the alternate controller. */
		arvmSyncPausedAltState(446),
		/** Role change has paused due to issues with required data synchronization. */
		arvmRoleChangePaused(447),
		/** The lowest aligned LBA for the physical sector of an emulation was found to be non-zero and is therefore not supported. */
		driveIncompatibleAlignmentForEmulationDrive(448),
		/** One or more Soyuz expansion channels are not externally connected to the alternate controller due to cabling or expansion tray power issues. One or both of the controllers may have completely lost access to one or more expansion trays. */
		lossOfExternalRedundancy(449),
		/** The primary array is functioning in an asynchronous write mode but the secondary is set to synchronous write mode. */
		rvmWriteModeInconsistent(450),
		/** The controller detected an HBA cabled to a drive channel. To protect the array, the controller will attempt to disable the SAS port within the array that is attached to the HBA. */
		sasHostMiswire(451),
		/** The controller detected that the two drive channels have been wired together. To protect the array, the controller will attempt to disable the expansion ports for one of the drive channels. */
		sasCrossMiswire(452),
		/** The controller detected a loop in the SAS domain that constitutes a drive channel. To protect the array, the controller will attempt to break the loop by disabling the expansion-out ports on the affected channel. */
		sasLoopMiswire(453),
		/** A copy then fail operation is waiting on the user to identify a suitable hot spare drive. */
		copyThenFailWaitingOnHotSpare(454),
		/** This is present if a controller is locked down due to detecting enough missing drives that if left alone would result in failed volumes. This may be the result of an enclosure power loss or cable connection problem. */
		missingDriveLockdown(455),
		/** This recovery failure type is logged when the HICs on a controller collectively support more than two interface protocols. */
		hicConfigurationOoc(456),
		/** The copy then fail operation is waiting for additional capacity in the disk pool. */
		copyThenFailWaitingOnDdpCapacity(457),
		/** The controller has automatically gone into service mode due to the detection of a PI error. */
		piErrorServiceMode(458),
		/** The controller has gone into lockdown mode due to the detection of PI errors on all controllers in the array. */
		piErrorLockdown(459),
		/** The controller has detected an error on the backend SAS channel during the SAS discovery phase. */
		sasPortDiscoveryError(460),
		/** Unable to resolve the domain name given for the Primary or Secondary NTP Server */
		netNtpResolutionFail(465),
		/** NTP Server unavailable or SNTP query failed */
		netNtpQueryFail(466),
		/** The Primary and Secondary configured NTP server names cannot be resolved, or cannot be reached, or the queries fail. */
		netNtpServiceUnavailable(467),
		/** The multipath driver for the specified host is not behaving as expected, indicating either the host type is incorrect or there is a configuration issue on the host. */
		multipathConfigurationError(474),
		/** The specified host has lost connectivity with one controller in the array. */
		hostRedundancyLost(475),
		/** This Recovery Guru is raised when excessive controller reboots have been detected. */
		excessiveRebootsDetected(476),
		/** The specified controller fails to flush dirty cache data on failed volume(s) possibly due to offlined drives. Replacing the controller may result in loss of data. */
		cacheNotFlushedOnOnlyCtlr(477),
		__UNDEFINED(464378545);

		public final int value;

		private RecoveryFailureType(int v) {
			this.value = v;
		}
}
