package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains client authentication information. It must be included as part of the RPC message header's authentication field for any RPC operation that changes the state of the array or its components. The array controller will inspect this structure to ensure that an authorized client has submitted such a request. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(351)
public class SYMbolAuthentication implements Serializable {
	public SYMbolAuthentication() {
	}

	/** The IP address of the client that is submitting the request. */
	@io.swagger.annotations.ApiModelProperty(value ="The IP address of the client that is submitting the request." , required = true)
	@XmlElement(required = true)
	private int clientIp;

	/** @return The IP address of the client that is submitting the request. */
	public int getClientIp() {
		return this.clientIp;
	}
	/** @param x The IP address of the client that is submitting the request. */
	public void setClientIp(int x) {
		this.clientIp = x;
	}

	/** The world-wide name of the storage array to which the request is being submitted. */
	@io.swagger.annotations.ApiModelProperty(value ="The world-wide name of the storage array to which the request is being submitted." , required = true)
	@XmlElement(required = true)
	private SAIdentifier arrayId;

	/** @return The world-wide name of the storage array to which the request is being submitted. */
	public SAIdentifier getArrayId() {
		return this.arrayId;
	}
	/** @param x The world-wide name of the storage array to which the request is being submitted. */
	public void setArrayId(SAIdentifier x) {
		this.arrayId = x;
	}

	/** The current configuration generation number of the array to which the request is being submitted. */
	@io.swagger.annotations.ApiModelProperty(value ="The current configuration generation number of the array to which the request is being submitted." , required = true)
	@XmlElement(required = true)
	private long configGeneration;

	/** @return The current configuration generation number of the array to which the request is being submitted. */
	public long getConfigGeneration() {
		return this.configGeneration;
	}
	/** @param x The current configuration generation number of the array to which the request is being submitted. */
	public void setConfigGeneration(long x) {
		this.configGeneration = x;
	}

	/** A byte array that contains the 20-byte message digest algorithm for the entire RPC message, computed using the SHA-1 algorithm. */
	@io.swagger.annotations.ApiModelProperty(value ="A byte array that contains the 20-byte message digest algorithm for the entire RPC message, computed using the SHA-1 algorithm." , required = true)
	@XmlElement(required = true)
	private String digest;

	/** @return A byte array that contains the 20-byte message digest algorithm for the entire RPC message, computed using the SHA-1 algorithm. */
	public String getDigest() {
		return this.digest;
	}
	/** @param x A byte array that contains the 20-byte message digest algorithm for the entire RPC message, computed using the SHA-1 algorithm. */
	public void setDigest(String x) {
		this.digest = x;
	}
}
