package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains information about a SAS port. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1096)
public class SasPort implements Serializable {
	public SasPort() {
	}

	/** The device on which the port resides. */
	@io.swagger.annotations.ApiModelProperty(value ="The device on which the port resides." , required = true)
	@XmlElement(required = true)
	private SasPortProviderDevice parent;

	/** @return The device on which the port resides. */
	public SasPortProviderDevice getParent() {
		return this.parent;
	}
	/** @param x The device on which the port resides. */
	public void setParent(SasPortProviderDevice x) {
		this.parent = x;
	}

	/** An indication of what device is attached to this port. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of what device is attached to this port." , required = true)
	@XmlElement(required = true)
	private SasAttachedDevice attachedDevice;

	/** @return An indication of what device is attached to this port. */
	public SasAttachedDevice getAttachedDevice() {
		return this.attachedDevice;
	}
	/** @param x An indication of what device is attached to this port. */
	public void setAttachedDevice(SasAttachedDevice x) {
		this.attachedDevice = x;
	}

	/** The state of the SAS port. */
	@io.swagger.annotations.ApiModelProperty(value ="The state of the SAS port." , required = true)
	@XmlElement(required = true)
	private SasPortState state = SasPortState.__UNDEFINED;

	/** @return The state of the SAS port. */
	public SasPortState getState() {
		return this.state;
	}
	/** @param x The state of the SAS port. */
	public void setState(SasPortState x) {
		this.state = x;
	}

	/** The type of miswire involving this port (or "none"). */
	@io.swagger.annotations.ApiModelProperty(value ="The type of miswire involving this port (or \"none\")." , required = true)
	@XmlElement(required = true)
	private SasMiswireType miswireType = SasMiswireType.__UNDEFINED;

	/** @return The type of miswire involving this port (or "none"). */
	public SasMiswireType getMiswireType() {
		return this.miswireType;
	}
	/** @param x The type of miswire involving this port (or "none"). */
	public void setMiswireType(SasMiswireType x) {
		this.miswireType = x;
	}

	/** A reference to the channel port object identifying the external connector associated with this port. If the port is not associated with an external connector, then this field is set to a null SYMbol ref. */
	@io.swagger.annotations.ApiModelProperty(value ="A reference to the channel port object identifying the external connector associated with this port. If the port is not associated with an external connector, then this field is set to a null SYMbol ref." , required = true)
	@XmlElement(required = true)
	private String channelPortRef;

	/** @return A reference to the channel port object identifying the external connector associated with this port. If the port is not associated with an external connector, then this field is set to a null SYMbol ref. */
	public String getChannelPortRef() {
		return this.channelPortRef;
	}
	/** @param x A reference to the channel port object identifying the external connector associated with this port. If the port is not associated with an external connector, then this field is set to a null SYMbol ref. */
	public void setChannelPortRef(String x) {
		this.channelPortRef = x;
	}

	/** A list of PHYs associated with this port. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of PHYs associated with this port." , required = true)
	@XmlElement(required = true)
	private SasPhy[] sasPhys;

	/** @return A list of PHYs associated with this port. */
	public SasPhy[] getSasPhys() {
		return this.sasPhys;
	}
	/** @param x A list of PHYs associated with this port. */
	public void setSasPhys(SasPhy[] x) {
		this.sasPhys = x;
	}

	/** Information about a SAS port that is type-dependent. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about a SAS port that is type-dependent." , required = true)
	@XmlElement(required = true)
	private SasPortTypeData portTypeData;

	/** @return Information about a SAS port that is type-dependent. */
	public SasPortTypeData getPortTypeData() {
		return this.portTypeData;
	}
	/** @param x Information about a SAS port that is type-dependent. */
	public void setPortTypeData(SasPortTypeData x) {
		this.portTypeData = x;
	}

	/** The SAS port connection mode. */
	@io.swagger.annotations.ApiModelProperty(value ="The SAS port connection mode." , required = true)
	@XmlElement(required = true)
	private SASPortMode portMode = SASPortMode.__UNDEFINED;

	/** @return The SAS port connection mode. */
	public SASPortMode getPortMode() {
		return this.portMode;
	}
	/** @param x The SAS port connection mode. */
	public void setPortMode(SASPortMode x) {
		this.portMode = x;
	}

	/** The domain number identifies which SAS domain this element is a part of. Domain numbers are arbitrarily assigned by the firmware and are consistent on a per controller basis -- but not across controllers. So, the contents of domains will be consistent across controllers but the number identifying a particular domain may not be. */
	@io.swagger.annotations.ApiModelProperty(value ="The domain number identifies which SAS domain this element is a part of. Domain numbers are arbitrarily assigned by the firmware and are consistent on a per controller basis -- but not across controllers. So, the contents of domains will be consistent across controllers but the number identifying a particular domain may not be." , required = true)
	@XmlElement(required = true)
	private int domainNumber;

	/** @return The domain number identifies which SAS domain this element is a part of. Domain numbers are arbitrarily assigned by the firmware and are consistent on a per controller basis -- but not across controllers. So, the contents of domains will be consistent across controllers but the number identifying a particular domain may not be. */
	public int getDomainNumber() {
		return this.domainNumber;
	}
	/** @param x The domain number identifies which SAS domain this element is a part of. Domain numbers are arbitrarily assigned by the firmware and are consistent on a per controller basis -- but not across controllers. So, the contents of domains will be consistent across controllers but the number identifying a particular domain may not be. */
	public void setDomainNumber(int x) {
		this.domainNumber = x;
	}

	/** This ref identifies the connector on the attached device for a drive channel who's external port is connected to another device. */
	@io.swagger.annotations.ApiModelProperty(value ="This ref identifies the connector on the attached device for a drive channel who's external port is connected to another device." , required = true)
	@XmlElement(required = true)
	private String attachedChannelPortRef;

	/** @return This ref identifies the connector on the attached device for a drive channel who's external port is connected to another device. */
	public String getAttachedChannelPortRef() {
		return this.attachedChannelPortRef;
	}
	/** @param x This ref identifies the connector on the attached device for a drive channel who's external port is connected to another device. */
	public void setAttachedChannelPortRef(String x) {
		this.attachedChannelPortRef = x;
	}

	/** This element contains the status of the SAS discovery - the status is a bit field and could indicate a successful discovery or could indicate one or more failure conditions (indicated by one or more error flags being set). */
	@io.swagger.annotations.ApiModelProperty(value ="This element contains the status of the SAS discovery - the status is a bit field and could indicate a successful discovery or could indicate one or more failure conditions (indicated by one or more error flags being set)." , required = true)
	@XmlElement(required = true)
	private int discoveryStatus;

	/** @return This element contains the status of the SAS discovery - the status is a bit field and could indicate a successful discovery or could indicate one or more failure conditions (indicated by one or more error flags being set). */
	public int getDiscoveryStatus() {
		return this.discoveryStatus;
	}
	/** @param x This element contains the status of the SAS discovery - the status is a bit field and could indicate a successful discovery or could indicate one or more failure conditions (indicated by one or more error flags being set). */
	public void setDiscoveryStatus(int x) {
		this.discoveryStatus = x;
	}
}
