package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains all relevant information about a volume candidate, which is a specification for a volume that can be created via a call to the createVolume procedure. Note that volume candidate objects cannot be created arbitrarily by the client. They must be obtained from the controller via a getVolumeCandidates procedure call. Once obtained, they must then be conveyed as a parameter to the the createVolume procedure when creating a new volume. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(928)
public class VolumeCandidate implements Serializable {
	public VolumeCandidate() {
	}

	/** The RAID level of the potential volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The RAID level of the potential volume." , required = true)
	@XmlElement(required = true)
	private RAIDLevel raidLevel = RAIDLevel.__UNDEFINED;

	/** @return The RAID level of the potential volume. */
	public RAIDLevel getRaidLevel() {
		return this.raidLevel;
	}
	/** @param x The RAID level of the potential volume. */
	public void setRaidLevel(RAIDLevel x) {
		this.raidLevel = x;
	}

	/** This field is set to true if the candidate has tray loss protection. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is set to true if the candidate has tray loss protection." , required = true)
	@XmlElement(required = true)
	private boolean trayLossProtection;

	/** @return This field is set to true if the candidate has tray loss protection. */
	public boolean isTrayLossProtection() {
		return this.trayLossProtection;
	}
	/** @param x This field is set to true if the candidate has tray loss protection. */
	public void setTrayLossProtection(boolean x) {
		this.trayLossProtection = x;
	}

	/** This value is the maximum allowed user data storage capacity for the volume if the smallest possible segment is used in creating the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="This value is the maximum allowed user data storage capacity for the volume if the smallest possible segment is used in creating the volume." , required = true)
	@XmlElement(required = true)
	private long rawSize;

	/** @return This value is the maximum allowed user data storage capacity for the volume if the smallest possible segment is used in creating the volume. */
	public long getRawSize() {
		return this.rawSize;
	}
	/** @param x This value is the maximum allowed user data storage capacity for the volume if the smallest possible segment is used in creating the volume. */
	public void setRawSize(long x) {
		this.rawSize = x;
	}

	/** This value is the maximum allowed user data storage capacity for the volume if the largest possible segment is used in creating the volume. */
	@io.swagger.annotations.ApiModelProperty(value ="This value is the maximum allowed user data storage capacity for the volume if the largest possible segment is used in creating the volume." , required = true)
	@XmlElement(required = true)
	private long usableSize;

	/** @return This value is the maximum allowed user data storage capacity for the volume if the largest possible segment is used in creating the volume. */
	public long getUsableSize() {
		return this.usableSize;
	}
	/** @param x This value is the maximum allowed user data storage capacity for the volume if the largest possible segment is used in creating the volume. */
	public void setUsableSize(long x) {
		this.usableSize = x;
	}

	/** The number of drives in the potential volume's volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of drives in the potential volume's volume group." , required = true)
	@XmlElement(required = true)
	private int driveCount;

	/** @return The number of drives in the potential volume's volume group. */
	public int getDriveCount() {
		return this.driveCount;
	}
	/** @param x The number of drives in the potential volume's volume group. */
	public void setDriveCount(int x) {
		this.driveCount = x;
	}

	/** The reference value of the free extent on which the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_FREE_EXTENT. */
	@io.swagger.annotations.ApiModelProperty(value ="The reference value of the free extent on which the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_FREE_EXTENT." , required = true)
	@XmlElement(required = true)
	private String freeExtentRef;

	/** @return The reference value of the free extent on which the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_FREE_EXTENT. */
	public String getFreeExtentRef() {
		return this.freeExtentRef;
	}
	/** @param x The reference value of the free extent on which the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_FREE_EXTENT. */
	public void setFreeExtentRef(String x) {
		this.freeExtentRef = x;
	}

	/** A list of the reference values of the drives on which the volume group for the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_MANUAL. */
	@io.swagger.annotations.ApiModelProperty(value ="A list of the reference values of the drives on which the volume group for the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_MANUAL." , required = true)
	@XmlElement(required = true)
	private DriveRefList driveRefList;

	/** @return A list of the reference values of the drives on which the volume group for the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_MANUAL. */
	public DriveRefList getDriveRefList() {
		return this.driveRefList;
	}
	/** @param x A list of the reference values of the drives on which the volume group for the potential volume would be created. This field will be valid only if the volume candidate was obtained using a candidate selection type of CANDIDATE_SEL_MANUAL. */
	public void setDriveRefList(DriveRefList x) {
		this.driveRefList = x;
	}

	/** The type of candidate selection that was used to obtain this volume candidate. */
	@io.swagger.annotations.ApiModelProperty(value ="The type of candidate selection that was used to obtain this volume candidate." , required = true)
	@XmlElement(required = true)
	private CandidateSelectionType candidateSelectionType = CandidateSelectionType.__UNDEFINED;

	/** @return The type of candidate selection that was used to obtain this volume candidate. */
	public CandidateSelectionType getCandidateSelectionType() {
		return this.candidateSelectionType;
	}
	/** @param x The type of candidate selection that was used to obtain this volume candidate. */
	public void setCandidateSelectionType(CandidateSelectionType x) {
		this.candidateSelectionType = x;
	}

	/** True, if all drives have matching spindle speed. */
	@io.swagger.annotations.ApiModelProperty(value ="True, if all drives have matching spindle speed." , required = true)
	@XmlElement(required = true)
	private boolean spindleSpeedMatch;

	/** @return True, if all drives have matching spindle speed. */
	public boolean isSpindleSpeedMatch() {
		return this.spindleSpeedMatch;
	}
	/** @param x True, if all drives have matching spindle speed. */
	public void setSpindleSpeedMatch(boolean x) {
		this.spindleSpeedMatch = x;
	}

	/** True, if all drives have matching spindle speed. */
	@io.swagger.annotations.ApiModelProperty(value ="True, if all drives have matching spindle speed." , required = true)
	@XmlElement(required = true)
	private int spindleSpeed;

	/** @return True, if all drives have matching spindle speed. */
	public int getSpindleSpeed() {
		return this.spindleSpeed;
	}
	/** @param x True, if all drives have matching spindle speed. */
	public void setSpindleSpeed(int x) {
		this.spindleSpeed = x;
	}

	/** The physical drive type. */
	@io.swagger.annotations.ApiModelProperty(value ="The physical drive type." , required = true)
	@XmlElement(required = true)
	private PhysicalDriveType phyDriveType = PhysicalDriveType.__UNDEFINED;

	/** @return The physical drive type. */
	public PhysicalDriveType getPhyDriveType() {
		return this.phyDriveType;
	}
	/** @param x The physical drive type. */
	public void setPhyDriveType(PhysicalDriveType x) {
		this.phyDriveType = x;
	}

	/** True if dynamic segment sizing pre-allocation will be enabled for the volume created from this candidate, otherwise false. */
	@io.swagger.annotations.ApiModelProperty(value ="True if dynamic segment sizing pre-allocation will be enabled for the volume created from this candidate, otherwise false." , required = true)
	@XmlElement(required = true)
	private boolean dssPreallocEnabled;

	/** @return True if dynamic segment sizing pre-allocation will be enabled for the volume created from this candidate, otherwise false. */
	public boolean isDssPreallocEnabled() {
		return this.dssPreallocEnabled;
	}
	/** @param x True if dynamic segment sizing pre-allocation will be enabled for the volume created from this candidate, otherwise false. */
	public void setDssPreallocEnabled(boolean x) {
		this.dssPreallocEnabled = x;
	}

	/** The desired security level of the drive group. */
	@io.swagger.annotations.ApiModelProperty(value ="The desired security level of the drive group." , required = true)
	@XmlElement(required = true)
	private SecurityType securityType = SecurityType.__UNDEFINED;

	/** @return The desired security level of the drive group. */
	public SecurityType getSecurityType() {
		return this.securityType;
	}
	/** @param x The desired security level of the drive group. */
	public void setSecurityType(SecurityType x) {
		this.securityType = x;
	}

	/** This field is set to true when the volume group has drawer loss protection; otherwise it is set to false */
	@io.swagger.annotations.ApiModelProperty(value ="This field is set to true when the volume group has drawer loss protection; otherwise it is set to false" , required = true)
	@XmlElement(required = true)
	private boolean drawerLossProtection;

	/** @return This field is set to true when the volume group has drawer loss protection; otherwise it is set to false */
	public boolean isDrawerLossProtection() {
		return this.drawerLossProtection;
	}
	/** @param x This field is set to true when the volume group has drawer loss protection; otherwise it is set to false */
	public void setDrawerLossProtection(boolean x) {
		this.drawerLossProtection = x;
	}

	/** Drive media type (HDD or SSD) of the volume candidate. */
	@io.swagger.annotations.ApiModelProperty(value ="Drive media type (HDD or SSD) of the volume candidate." , required = true)
	@XmlElement(required = true)
	private DriveMediaType driveMediaType = DriveMediaType.__UNDEFINED;

	/** @return Drive media type (HDD or SSD) of the volume candidate. */
	public DriveMediaType getDriveMediaType() {
		return this.driveMediaType;
	}
	/** @param x Drive media type (HDD or SSD) of the volume candidate. */
	public void setDriveMediaType(DriveMediaType x) {
		this.driveMediaType = x;
	}

	/** This field is no longer used. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is no longer used." , required = true)
	@XmlElement(required = true)
	private boolean protectionInformationCapable;

	/** @return This field is no longer used. */
	public boolean isProtectionInformationCapable() {
		return this.protectionInformationCapable;
	}
	/** @param x This field is no longer used. */
	public void setProtectionInformationCapable(boolean x) {
		this.protectionInformationCapable = x;
	}

	/** This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group where the volume candidate resides are Protection Information (PI) capable. It also contains the protection type for the volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group where the volume candidate resides are Protection Information (PI) capable. It also contains the protection type for the volume group." , required = true)
	@XmlElement(required = true)
	private ProtectionInformationCapabilities protectionInformationCapabilities;

	/** @return This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group where the volume candidate resides are Protection Information (PI) capable. It also contains the protection type for the volume group. */
	public ProtectionInformationCapabilities getProtectionInformationCapabilities() {
		return this.protectionInformationCapabilities;
	}
	/** @param x This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group where the volume candidate resides are Protection Information (PI) capable. It also contains the protection type for the volume group. */
	public void setProtectionInformationCapabilities(ProtectionInformationCapabilities x) {
		this.protectionInformationCapabilities = x;
	}

	/** Information about the Volume Candidate. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about the Volume Candidate." , required = true)
	@XmlElement(required = true)
	private VolumeCandidateTypeData volumeCandidateData;

	/** @return Information about the Volume Candidate. */
	public VolumeCandidateTypeData getVolumeCandidateData() {
		return this.volumeCandidateData;
	}
	/** @param x Information about the Volume Candidate. */
	public void setVolumeCandidateData(VolumeCandidateTypeData x) {
		this.volumeCandidateData = x;
	}

	/** Identifies the drive block format of the volume candidate. */
	@io.swagger.annotations.ApiModelProperty(value ="Identifies the drive block format of the volume candidate." , required = true)
	@XmlElement(required = true)
	private DriveBlockFormat driveBlockFormat = DriveBlockFormat.__UNDEFINED;

	/** @return Identifies the drive block format of the volume candidate. */
	public DriveBlockFormat getDriveBlockFormat() {
		return this.driveBlockFormat;
	}
	/** @param x Identifies the drive block format of the volume candidate. */
	public void setDriveBlockFormat(DriveBlockFormat x) {
		this.driveBlockFormat = x;
	}

	/** Determines whether or not reserved space is allocated on the drives in the volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="Determines whether or not reserved space is allocated on the drives in the volume group." , required = true)
	@XmlElement(required = true)
	private boolean allocateReservedSpace;

	/** @return Determines whether or not reserved space is allocated on the drives in the volume group. */
	public boolean isAllocateReservedSpace() {
		return this.allocateReservedSpace;
	}
	/** @param x Determines whether or not reserved space is allocated on the drives in the volume group. */
	public void setAllocateReservedSpace(boolean x) {
		this.allocateReservedSpace = x;
	}

	/** Describes the overall security level of the drive set. Values can include: FDE only, FIPS only, mixed, or no security. Used along with the SecurityType field. */
	@io.swagger.annotations.ApiModelProperty(value ="Describes the overall security level of the drive set. Values can include: FDE only, FIPS only, mixed, or no security. Used along with the SecurityType field." , required = true)
	@XmlElement(required = true)
	private SecurityLevel securityLevel = SecurityLevel.__UNDEFINED;

	/** @return Describes the overall security level of the drive set. Values can include: FDE only, FIPS only, mixed, or no security. Used along with the SecurityType field. */
	public SecurityLevel getSecurityLevel() {
		return this.securityLevel;
	}
	/** @param x Describes the overall security level of the drive set. Values can include: FDE only, FIPS only, mixed, or no security. Used along with the SecurityType field. */
	public void setSecurityLevel(SecurityLevel x) {
		this.securityLevel = x;
	}
}
