package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used as the argument to the getVolumeCandidates procedure. It specifies the type of volume candidate(s) desired, and also provides further information to the controller about which candidates to return. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(1077)
public class VolumeCandidateRequest implements Serializable {
	public VolumeCandidateRequest() {
	}

	/** This field contains the specification of the type of volume candidates that are desired, along with ancillary information that depends on the type of candidates. */
	@io.swagger.annotations.ApiModelProperty(value ="This field contains the specification of the type of volume candidates that are desired, along with ancillary information that depends on the type of candidates." , required = true)
	@XmlElement(required = true)
	private CandidateSelectionTypeData candidateSelectionType;

	/** @return This field contains the specification of the type of volume candidates that are desired, along with ancillary information that depends on the type of candidates. */
	public CandidateSelectionTypeData getCandidateSelectionType() {
		return this.candidateSelectionType;
	}
	/** @param x This field contains the specification of the type of volume candidates that are desired, along with ancillary information that depends on the type of candidates. */
	public void setCandidateSelectionType(CandidateSelectionTypeData x) {
		this.candidateSelectionType = x;
	}

	/** This field indicates that RAID level in which the caller is interested. It may be set to RAID_ALL if the client wishes to obtain volume candidate information about all possible RAID levels. */
	@io.swagger.annotations.ApiModelProperty(value ="This field indicates that RAID level in which the caller is interested. It may be set to RAID_ALL if the client wishes to obtain volume candidate information about all possible RAID levels." , required = true)
	@XmlElement(required = true)
	private RAIDLevel raidLevel = RAIDLevel.__UNDEFINED;

	/** @return This field indicates that RAID level in which the caller is interested. It may be set to RAID_ALL if the client wishes to obtain volume candidate information about all possible RAID levels. */
	public RAIDLevel getRaidLevel() {
		return this.raidLevel;
	}
	/** @param x This field indicates that RAID level in which the caller is interested. It may be set to RAID_ALL if the client wishes to obtain volume candidate information about all possible RAID levels. */
	public void setRaidLevel(RAIDLevel x) {
		this.raidLevel = x;
	}

	/** The desired physical drive type. */
	@io.swagger.annotations.ApiModelProperty(value ="The desired physical drive type." , required = true)
	@XmlElement(required = true)
	private PhysicalDriveType phyDriveType = PhysicalDriveType.__UNDEFINED;

	/** @return The desired physical drive type. */
	public PhysicalDriveType getPhyDriveType() {
		return this.phyDriveType;
	}
	/** @param x The desired physical drive type. */
	public void setPhyDriveType(PhysicalDriveType x) {
		this.phyDriveType = x;
	}

	/** This field indicates whether or not the firmware should base the search for candidates on the DSS preallocation calculation. */
	@io.swagger.annotations.ApiModelProperty(value ="This field indicates whether or not the firmware should base the search for candidates on the DSS preallocation calculation." , required = true)
	@XmlElement(required = true)
	private boolean dssPreallocEnabled;

	/** @return This field indicates whether or not the firmware should base the search for candidates on the DSS preallocation calculation. */
	public boolean isDssPreallocEnabled() {
		return this.dssPreallocEnabled;
	}
	/** @param x This field indicates whether or not the firmware should base the search for candidates on the DSS preallocation calculation. */
	public void setDssPreallocEnabled(boolean x) {
		this.dssPreallocEnabled = x;
	}

	/** Desired security type of the drive group (i.e. secure vs. not secure). */
	@io.swagger.annotations.ApiModelProperty(value ="Desired security type of the drive group (i.e. secure vs. not secure)." , required = true)
	@XmlElement(required = true)
	private SecurityType securityType = SecurityType.__UNDEFINED;

	/** @return Desired security type of the drive group (i.e. secure vs. not secure). */
	public SecurityType getSecurityType() {
		return this.securityType;
	}
	/** @param x Desired security type of the drive group (i.e. secure vs. not secure). */
	public void setSecurityType(SecurityType x) {
		this.securityType = x;
	}

	/** Drive media type (HDD or SSD) of the volume candidate. */
	@io.swagger.annotations.ApiModelProperty(value ="Drive media type (HDD or SSD) of the volume candidate." , required = true)
	@XmlElement(required = true)
	private DriveMediaType driveMediaType = DriveMediaType.__UNDEFINED;

	/** @return Drive media type (HDD or SSD) of the volume candidate. */
	public DriveMediaType getDriveMediaType() {
		return this.driveMediaType;
	}
	/** @param x Drive media type (HDD or SSD) of the volume candidate. */
	public void setDriveMediaType(DriveMediaType x) {
		this.driveMediaType = x;
	}

	/** If true, only PI-capable drives considered for volume candidates. */
	@io.swagger.annotations.ApiModelProperty(value ="If true, only PI-capable drives considered for volume candidates." , required = true)
	@XmlElement(required = true)
	private boolean onlyProtectionInformationCapable;

	/** @return If true, only PI-capable drives considered for volume candidates. */
	public boolean isOnlyProtectionInformationCapable() {
		return this.onlyProtectionInformationCapable;
	}
	/** @param x If true, only PI-capable drives considered for volume candidates. */
	public void setOnlyProtectionInformationCapable(boolean x) {
		this.onlyProtectionInformationCapable = x;
	}

	/** Information about the Volume Candidate Request. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about the Volume Candidate Request." , required = true)
	@XmlElement(required = true)
	private VolumeCandidateRequestTypeData volumeCandidateRequestData;

	/** @return Information about the Volume Candidate Request. */
	public VolumeCandidateRequestTypeData getVolumeCandidateRequestData() {
		return this.volumeCandidateRequestData;
	}
	/** @param x Information about the Volume Candidate Request. */
	public void setVolumeCandidateRequestData(VolumeCandidateRequestTypeData x) {
		this.volumeCandidateRequestData = x;
	}

	/** If true, allocate reserved space when creating a new volume group. Ignore when creating a volume in an existing volume group */
	@io.swagger.annotations.ApiModelProperty(value ="If true, allocate reserved space when creating a new volume group. Ignore when creating a volume in an existing volume group" , required = true)
	@XmlElement(required = true)
	private boolean allocateReservedSpace;

	/** @return If true, allocate reserved space when creating a new volume group. Ignore when creating a volume in an existing volume group */
	public boolean isAllocateReservedSpace() {
		return this.allocateReservedSpace;
	}
	/** @param x If true, allocate reserved space when creating a new volume group. Ignore when creating a volume in an existing volume group */
	public void setAllocateReservedSpace(boolean x) {
		this.allocateReservedSpace = x;
	}

	/** The security level describes whether a set of drives should be comprised of FDE only, FIPS only, Mixed, or no security. This field is used along with the SecurityType filed to fully define the drive set. */
	@io.swagger.annotations.ApiModelProperty(value ="The security level describes whether a set of drives should be comprised of FDE only, FIPS only, Mixed, or no security. This field is used along with the SecurityType filed to fully define the drive set." , required = true)
	@XmlElement(required = true)
	private SecurityLevel securityLevel = SecurityLevel.__UNDEFINED;

	/** @return The security level describes whether a set of drives should be comprised of FDE only, FIPS only, Mixed, or no security. This field is used along with the SecurityType filed to fully define the drive set. */
	public SecurityLevel getSecurityLevel() {
		return this.securityLevel;
	}
	/** @param x The security level describes whether a set of drives should be comprised of FDE only, FIPS only, Mixed, or no security. This field is used along with the SecurityType filed to fully define the drive set. */
	public void setSecurityLevel(SecurityLevel x) {
		this.securityLevel = x;
	}
}
