package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey information about a volume group's attributes and current operational status. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(666)
public class VolumeGroup implements Serializable,devmgr.api.model.Identifiable,devmgr.api.model.Named {
	public VolumeGroup() {
	}

	/** A sequence number that uniquely identifies this volume group within the array in which it resides. Sequence numbers are assigned to volume groups when they are created or imported into a storage array. The controller assigns the lowest unused sequence number during a creation or import operation. */
	@io.swagger.annotations.ApiModelProperty(value ="A sequence number that uniquely identifies this volume group within the array in which it resides. Sequence numbers are assigned to volume groups when they are created or imported into a storage array. The controller assigns the lowest unused sequence number during a creation or import operation." , required = true)
	@XmlElement(required = true)
	private int sequenceNum;

	/** @return A sequence number that uniquely identifies this volume group within the array in which it resides. Sequence numbers are assigned to volume groups when they are created or imported into a storage array. The controller assigns the lowest unused sequence number during a creation or import operation. */
	public int getSequenceNum() {
		return this.sequenceNum;
	}
	/** @param x A sequence number that uniquely identifies this volume group within the array in which it resides. Sequence numbers are assigned to volume groups when they are created or imported into a storage array. The controller assigns the lowest unused sequence number during a creation or import operation. */
	public void setSequenceNum(int x) {
		this.sequenceNum = x;
	}

	/** An indication of whether the volume group is currently offline. A volume group can be taken offline by the operator in preparation for removing its drives and transporting them to another storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether the volume group is currently offline. A volume group can be taken offline by the operator in preparation for removing its drives and transporting them to another storage array." , required = true)
	@XmlElement(required = true)
	private boolean offline;

	/** @return An indication of whether the volume group is currently offline. A volume group can be taken offline by the operator in preparation for removing its drives and transporting them to another storage array. */
	public boolean isOffline() {
		return this.offline;
	}
	/** @param x An indication of whether the volume group is currently offline. A volume group can be taken offline by the operator in preparation for removing its drives and transporting them to another storage array. */
	public void setOffline(boolean x) {
		this.offline = x;
	}

	/** The RAID level associated with this volume group. If the storage array supports multiple RAID levels per volume group, this value will be set to RAID_ALL. Otherwise, it will indicate the precise RAID level defined for the volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="The RAID level associated with this volume group. If the storage array supports multiple RAID levels per volume group, this value will be set to RAID_ALL. Otherwise, it will indicate the precise RAID level defined for the volume group." , required = true)
	@XmlElement(required = true)
	private RAIDLevel raidLevel = RAIDLevel.__UNDEFINED;

	/** @return The RAID level associated with this volume group. If the storage array supports multiple RAID levels per volume group, this value will be set to RAID_ALL. Otherwise, it will indicate the precise RAID level defined for the volume group. */
	public RAIDLevel getRaidLevel() {
		return this.raidLevel;
	}
	/** @param x The RAID level associated with this volume group. If the storage array supports multiple RAID levels per volume group, this value will be set to RAID_ALL. Otherwise, it will indicate the precise RAID level defined for the volume group. */
	public void setRaidLevel(RAIDLevel x) {
		this.raidLevel = x;
	}

	/** A variable-length opaque field that provides the volume group's worldwide unique identification value. */
	@io.swagger.annotations.ApiModelProperty(value ="A variable-length opaque field that provides the volume group's worldwide unique identification value." , required = true)
	@XmlElement(required = true)
	private String worldWideName;

	/** @return A variable-length opaque field that provides the volume group's worldwide unique identification value. */
	public String getWorldWideName() {
		return this.worldWideName;
	}
	/** @param x A variable-length opaque field that provides the volume group's worldwide unique identification value. */
	public void setWorldWideName(String x) {
		this.worldWideName = x;
	}

	/** The unique identification value for this volume group. Other objects may use this reference value to refer to the volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="The unique identification value for this volume group. Other objects may use this reference value to refer to the volume group." , required = true)
	@XmlElement(required = true)
	private String volumeGroupRef;

	/** @return The unique identification value for this volume group. Other objects may use this reference value to refer to the volume group. */
	public String getVolumeGroupRef() {
		return this.volumeGroupRef;
	}
	/** @param x The unique identification value for this volume group. Other objects may use this reference value to refer to the volume group. */
	public void setVolumeGroupRef(String x) {
		this.volumeGroupRef = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved1;

	/** @return Reserved for future use. */
	public String getReserved1() {
		return this.reserved1;
	}
	/** @param x Reserved for future use. */
	public void setReserved1(String x) {
		this.reserved1 = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String reserved2;

	/** @return Reserved for future use. */
	public String getReserved2() {
		return this.reserved2;
	}
	/** @param x Reserved for future use. */
	public void setReserved2(String x) {
		this.reserved2 = x;
	}

	/** An indication as to whether the volume group has tray loss protection. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication as to whether the volume group has tray loss protection." , required = true)
	@XmlElement(required = true)
	private boolean trayLossProtection;

	/** @return An indication as to whether the volume group has tray loss protection. */
	public boolean isTrayLossProtection() {
		return this.trayLossProtection;
	}
	/** @param x An indication as to whether the volume group has tray loss protection. */
	public void setTrayLossProtection(boolean x) {
		this.trayLossProtection = x;
	}

	/** The volume group label, which can be set by the user. */
	@io.swagger.annotations.ApiModelProperty(value ="The volume group label, which can be set by the user." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return The volume group label, which can be set by the user. */
	public String getLabel() {
		return this.label;
	}
	/** @param x The volume group label, which can be set by the user. */
	public void setLabel(String x) {
		this.label = x;
	}

	/** The state of the volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="The state of the volume group." , required = true)
	@XmlElement(required = true)
	private VolumeGroupState state = VolumeGroupState.__UNDEFINED;

	/** @return The state of the volume group. */
	public VolumeGroupState getState() {
		return this.state;
	}
	/** @param x The state of the volume group. */
	public void setState(VolumeGroupState x) {
		this.state = x;
	}

	/** Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.) */
	@io.swagger.annotations.ApiModelProperty(value ="Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.)" , required = true)
	@XmlElement(required = true)
	private boolean spindleSpeedMatch;

	/** @return Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.) */
	public boolean isSpindleSpeedMatch() {
		return this.spindleSpeedMatch;
	}
	/** @param x Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.) */
	public void setSpindleSpeedMatch(boolean x) {
		this.spindleSpeedMatch = x;
	}

	/** Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.) */
	@io.swagger.annotations.ApiModelProperty(value ="Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.)" , required = true)
	@XmlElement(required = true)
	private int spindleSpeed;

	/** @return Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.) */
	public int getSpindleSpeed() {
		return this.spindleSpeed;
	}
	/** @param x Set to true if all of the drives in the group have matching normalized spindle speeds. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.) */
	public void setSpindleSpeed(int x) {
		this.spindleSpeed = x;
	}

	/** True if the volume group contains incompatible drives that have been locked out. */
	@io.swagger.annotations.ApiModelProperty(value ="True if the volume group contains incompatible drives that have been locked out." , required = true)
	@XmlElement(required = true)
	private boolean isInaccessible;

	/** @return True if the volume group contains incompatible drives that have been locked out. */
	public boolean isIsInaccessible() {
		return this.isInaccessible;
	}
	/** @param x True if the volume group contains incompatible drives that have been locked out. */
	public void setIsInaccessible(boolean x) {
		this.isInaccessible = x;
	}

	/** security status of the drive group */
	@io.swagger.annotations.ApiModelProperty(value ="security status of the drive group" , required = true)
	@XmlElement(required = true)
	private SecurityType securityType = SecurityType.__UNDEFINED;

	/** @return security status of the drive group */
	public SecurityType getSecurityType() {
		return this.securityType;
	}
	/** @param x security status of the drive group */
	public void setSecurityType(SecurityType x) {
		this.securityType = x;
	}

	/** This field is set to true when the volume group has drawer loss protection; otherwise it is set to false */
	@io.swagger.annotations.ApiModelProperty(value ="This field is set to true when the volume group has drawer loss protection; otherwise it is set to false" , required = true)
	@XmlElement(required = true)
	private boolean drawerLossProtection;

	/** @return This field is set to true when the volume group has drawer loss protection; otherwise it is set to false */
	public boolean isDrawerLossProtection() {
		return this.drawerLossProtection;
	}
	/** @param x This field is set to true when the volume group has drawer loss protection; otherwise it is set to false */
	public void setDrawerLossProtection(boolean x) {
		this.drawerLossProtection = x;
	}

	/** This field is no longer used. */
	@io.swagger.annotations.ApiModelProperty(value ="This field is no longer used." , required = true)
	@XmlElement(required = true)
	private boolean protectionInformationCapable;

	/** @return This field is no longer used. */
	public boolean isProtectionInformationCapable() {
		return this.protectionInformationCapable;
	}
	/** @param x This field is no longer used. */
	public void setProtectionInformationCapable(boolean x) {
		this.protectionInformationCapable = x;
	}

	/** This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group are Protection Information (PI) capable. It also contains a field that is set to the protection type for the volume group. */
	@io.swagger.annotations.ApiModelProperty(value ="This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group are Protection Information (PI) capable. It also contains a field that is set to the protection type for the volume group." , required = true)
	@XmlElement(required = true)
	private ProtectionInformationCapabilities protectionInformationCapabilities;

	/** @return This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group are Protection Information (PI) capable. It also contains a field that is set to the protection type for the volume group. */
	public ProtectionInformationCapabilities getProtectionInformationCapabilities() {
		return this.protectionInformationCapabilities;
	}
	/** @param x This structure contains a protectionInformationCapable field which is set to true if all drives in the volume group are Protection Information (PI) capable. It also contains a field that is set to the protection type for the volume group. */
	public void setProtectionInformationCapabilities(ProtectionInformationCapabilities x) {
		this.protectionInformationCapabilities = x;
	}

	/** Information about the Volume Group. */
	@io.swagger.annotations.ApiModelProperty(value ="Information about the Volume Group." , required = true)
	@XmlElement(required = true)
	private VolumeGroupTypeData volumeGroupData;

	/** @return Information about the Volume Group. */
	public VolumeGroupTypeData getVolumeGroupData() {
		return this.volumeGroupData;
	}
	/** @param x Information about the Volume Group. */
	public void setVolumeGroupData(VolumeGroupTypeData x) {
		this.volumeGroupData = x;
	}

	/** the volume group usage. */
	@io.swagger.annotations.ApiModelProperty(value ="the volume group usage." , required = true)
	@XmlElement(required = true)
	private VolumeGroupUsage usage = VolumeGroupUsage.__UNDEFINED;

	/** @return the volume group usage. */
	public VolumeGroupUsage getUsage() {
		return this.usage;
	}
	/** @param x the volume group usage. */
	public void setUsage(VolumeGroupUsage x) {
		this.usage = x;
	}

	/** Identifies the drive block format of the volume candidate. */
	@io.swagger.annotations.ApiModelProperty(value ="Identifies the drive block format of the volume candidate." , required = true)
	@XmlElement(required = true)
	private DriveBlockFormat driveBlockFormat = DriveBlockFormat.__UNDEFINED;

	/** @return Identifies the drive block format of the volume candidate. */
	public DriveBlockFormat getDriveBlockFormat() {
		return this.driveBlockFormat;
	}
	/** @param x Identifies the drive block format of the volume candidate. */
	public void setDriveBlockFormat(DriveBlockFormat x) {
		this.driveBlockFormat = x;
	}

	/** This field will be used to report whether or not reserved space has been claimed on all drives in the volume group. The recovery-volume script will include this field for each volume group record it creates, so that during volume recovery the volume group is recreated correctly. */
	@io.swagger.annotations.ApiModelProperty(value ="This field will be used to report whether or not reserved space has been claimed on all drives in the volume group. The recovery-volume script will include this field for each volume group record it creates, so that during volume recovery the volume group is recreated correctly." , required = true)
	@XmlElement(required = true)
	private boolean reservedSpaceAllocated;

	/** @return This field will be used to report whether or not reserved space has been claimed on all drives in the volume group. The recovery-volume script will include this field for each volume group record it creates, so that during volume recovery the volume group is recreated correctly. */
	public boolean isReservedSpaceAllocated() {
		return this.reservedSpaceAllocated;
	}
	/** @param x This field will be used to report whether or not reserved space has been claimed on all drives in the volume group. The recovery-volume script will include this field for each volume group record it creates, so that during volume recovery the volume group is recreated correctly. */
	public void setReservedSpaceAllocated(boolean x) {
		this.reservedSpaceAllocated = x;
	}

	/** Refines the information in the securityType field to describe the set of drives. */
	@io.swagger.annotations.ApiModelProperty(value ="Refines the information in the securityType field to describe the set of drives." , required = true)
	@XmlElement(required = true)
	private SecurityLevel securityLevel = SecurityLevel.__UNDEFINED;

	/** @return Refines the information in the securityType field to describe the set of drives. */
	public SecurityLevel getSecurityLevel() {
		return this.securityLevel;
	}
	/** @param x Refines the information in the securityType field to describe the set of drives. */
	public void setSecurityLevel(SecurityLevel x) {
		this.securityLevel = x;
	}
	@Override
	public String getId(){
		return volumeGroupRef;
	}
	@Override
	public String getName(){
		return label;
	}
}
