/*******************************************************************************
 * Copyright 2013 NetApp Inc.  All rights reserved.
 ******************************************************************************/

package devmgr.api.symbolutils;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;


public class ByteUtils
{
    public static String getUnicodeEncoding() {
        return UNICODE_ENCODING;
    }

    private static final String UNICODE_ENCODING = "UTF-16BE";
    private static final byte rmask = 0x0f;
    private static final byte lmask = (byte) 0xf0;
    private static final char[] hexCharTable = new char[]
    {
        '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
    };
    
    public static String getHexString(byte[] data){
    	return getHexString(data,0,data.length);
    }

    
    /**
     * Returns the hex string for the byte data
     * @param data data to use
     * @param start Start index, inclusive
     * @param end end index, exclusive
     * @return  A hex String
     */
    public static String getHexString(byte[] data, int start, int end)
    {
        StringBuilder buf = new StringBuilder();
        for (int i = start; i < end; i++)
        {
            byte b = data[i];
            byte l = (byte) ((b & lmask));
            l = (byte) (l >> 4);
            l = (byte) (l & rmask);
            byte r = (byte) (b & rmask);
            char lc = hexCharTable[l];
            char rc = hexCharTable[r];
            buf.append(lc);
            buf.append(rc);
        }
        return buf.toString().toUpperCase();
    }



    public static byte[] hexStringToByteArray(String s)
    {
        if ( s.contains(":")) {
            s= s.replaceAll(Pattern.quote(":"), "");
        }

        int len = s.length();
        byte[] data = new byte[len / 2];
        for (int i = 0; i < len; i += 2)
        {
            final int digit1 = Character.digit(s.charAt(i), 16);
            final int digit2 = Character.digit(s.charAt(i + 1), 16);
            data[i / 2] = (byte) ((digit1 << 4)  + digit2);
        }
        return data;
    }

    @Deprecated
    static public String getIpAddressString(String hexString){
        //AC147B42
        if (hexString.length() != 8){
            throw new IllegalArgumentException("Not a proper hex string");
        }
        byte[] data=new byte[4];
        String s;
        int n;
        s=hexString.substring(0,2);
        n=Integer.parseInt(s,16);
        data[0]=(byte) (n&0x000000ff);

        s=hexString.substring(2, 4);
        n=Integer.parseInt(s,16);
        data[1]=(byte) (n&0x000000ff);

        s=hexString.substring(4,6);
        n=Integer.parseInt(s,16);
        data[2]=(byte) (n&0x000000ff);

        s=hexString.substring(6,8);
        n=Integer.parseInt(s,16);
        data[3]=(byte) (n&0x000000ff);

        String ret = getIpAddressString(data);
        return ret;
    }

    /**
     * Converts a byte[] to an IP address.  This works for both Ipv4 and Ipv6.
     * @param data
     * @return
     */
    static public String getIpAddressString(byte[] data){
        StringBuffer ipAddrStr = new StringBuffer();
        if (data != null)
        {
            for (int i = 0; i < data.length; i++)
            {
                ipAddrStr.append(Integer.toString(data[i] & 0xFF));
                if (i < data.length - 1)
                {
                    ipAddrStr.append(".");
                }
            }
        }
        return ipAddrStr.toString();
    }
    static public byte[] getIPByteArray(String ipAddr) {
        byte[] ret=new byte[4];
        String [] parts=ipAddr.split("\\.");
        if (parts.length != 4){
            return null;
        }
        for (int i=0;i<parts.length;i++){
            int n=Integer.parseInt(parts[i]);
            ret[i]=(byte)(n&0x000000ff);
        }
        return ret;
    }

    public static byte[] convertStringToUnicodeBytes(String in){
        byte[] bytes;
        try{

            bytes = in.getBytes(UNICODE_ENCODING);
        }catch (Exception e){
            bytes=null;
        }
        return bytes;
    }

    public static String bytesToIntString(byte[] data) {
        StringBuffer sbuf = new StringBuffer();
        int i;

        for (i = 0; i < data.length; i++) {
            if (i > 0) {
                sbuf.append('.');
            }
            sbuf.append(toInt(data[i], 2));
        }

        return sbuf.toString();
    }
    private static String toInt(int value, int width)
    {
        StringBuffer retBuf = new StringBuffer();
        String rep = Integer.toString(value);
        for(int i=rep.length(); i < width; i++)
            retBuf.append("0");
        retBuf.append(rep);
           
        return retBuf.toString();
    }

    /**
     * Handles a version string.  In the current "new" symbol the version byte arrays are strings but just HEX strings.
     * If I get to it, (BDM) they will be dotted interger strings, if not, this will convert them to dotted strings
     * @param in
     * @return
     */
    public static String handleVersionString(String in){
        //if the version string is already in . decimal format, just return it
        if (in.contains(".")){
            return in;
        }
        byte[] bits=hexStringToByteArray(in);
        String ret=bytesToIntString(bits);
        return ret;
    }

    /**
     * Trim the byte array by removing the '\0' character at tail.
     * <p/>
     * NOTES/ASSUMPTIONS: <BR>
     * None.
     *
     * @param byteArray byte[] the byte array to be trimmed.
     * @return trimmed byte array.
     */
    public static byte[] trimByteArray(byte[] byteArray)
    {
        char value;
        List<Byte> list = new ArrayList<Byte>();

        for (int i = 0; i < byteArray.length; i++) {
            value = (char) byteArray[i];

            if (value == '\0') {
                break;
            }
            list.add(byteArray[i]);
        }

        byte[] result = new byte[list.size()];
        for (int i = 0; i < list.size(); i++) {
            result[i] = list.get(i).byteValue();
        }

        return result;
    }

    /**
     * Convert hex values to chars.
     * Example: 3038313430623030 is converted to 08140b00
     * @param s the string of hex values to convert
     * @return the converted string
     */
    public static String hexStringToCharString(String s) {
        if (s == null){
            return null;
        }
        int len = s.length();
        StringBuffer buffer = new StringBuffer();
        for (int i = 0; i < len; i += 2) {
            final int digit1 = Character.digit(s.charAt(i), 16);
            final int digit2 = Character.digit(s.charAt(i + 1), 16);
            char dataChar = (char) ((digit1 << 4) + digit2);
            buffer.append(dataChar);
        }

        return buffer.toString();
    }
}